@@ -1,4 +1,4 @@
-from Cocoa import *
+from Cocoa import NSDocument
 
 class CurrencyConvBindingDocument (NSDocument):
     def windowNibName(self):
