@@ -1,4 +1,6 @@
 from PyObjCTools import AppHelper
 import CGraphController
+import CGraphModel
+import CGraphView
 
 AppHelper.runEventLoop()
