@@ -2,12 +2,15 @@
 Script for building the example.
 
 Usage:
-    python setup.py py2app
+    python3 setup.py py2app
 """
-from distutils.core import setup
-import py2app
+from setuptools import setup
 
 setup(
     app=["PythonBrowser.py"],
     data_files=["MainMenu.nib", "PythonBrowser.nib"],
+    setup_requires=[
+        "py2app",
+        "pyobjc-framework-Cocoa",
+    ]
 )
