@@ -1,34 +1,31 @@
-import objc
-from Foundation import *
-from AppKit import *
+import Cocoa
 import objc
 
 def serviceSelector(fn):
     # this is the signature of service selectors
-    return objc.selector(fn, signature="v@:@@o^@")
+    return objc.selector(fn, signature=b"v@:@@o^@")
 
 def ERROR(s):
     #NSLog(u"ERROR: %s", s)
     return s
 
-class ServiceTest(NSObject):
+class ServiceTest(Cocoa.NSObject):
 
     @serviceSelector
     def doOpenFileService_userData_error_(self, pboard, data, error):
-        #NSLog(u"doOpenFileService_userData_error_(%s, %s)", pboard, data)
         try:
             types = pboard.types()
             pboardString = None
-            if NSStringPboardType in types:
-                pboardString = pboard.stringForType_(NSStringPboardType)
+            if Cocoa.NSStringPboardType in types:
+                pboardString = pboard.stringForType_(Cocoa.NSStringPboardType)
             if pboardString is None:
-                return ERROR(NSLocalizedString(
+                return ERROR(Cocoa.NSLocalizedString(
                     "Error: Pasteboard doesn't contain a string.",
                     "Pasteboard couldn't give string."
                 ))
 
-            if not NSWorkspace.sharedWorkspace().openFile_(pboardString):
-                return ERROR(NSLocalizedString(
+            if not Cocoa.NSWorkspace.sharedWorkspace().openFile_(pboardString):
+                return ERROR(Cocoa.NSLocalizedString(
                     "Error: Couldn't open file %s.",
                     "Couldn't perform service operation for file %s."
                 ) % pboardString)
@@ -46,25 +43,25 @@ class ServiceTest(NSObject):
         try:
             types = pboard.types()
             pboardString = None
-            if NSStringPboardType in types:
-                pboardString = pboard.stringForType_(NSStringPboardType)
+            if Cocoa.NSStringPboardType in types:
+                pboardString = pboard.stringForType_(Cocoa.NSStringPboardType)
             if pboardString is None:
-                return ERROR(NSLocalizedString(
+                return ERROR(Cocoa.NSLocalizedString(
                     "Error: Pasteboard doesn't contain a string.",
                     "Pasteboard couldn't give string."
                 ))
 
-            newString = NSString.capitalizedString(pboardString)
+            newString = Cocoa.NSString.capitalizedString(pboardString)
 
             if not newString:
-                return ERROR(NSLocalizedString(
+                return ERROR(Cocoa.NSLocalizedString(
                     "Error: Couldn't capitalize string %s.",
                     "Couldn't perform service operation for string %s."
                 ) % pboardString)
 
-            types = [NSStringPboardType]
-            pboard.declareTypes_owner_([NSStringPboardType], None)
-            pboard.setString_forType_(newString, NSStringPboardType)
+            types = [Cocoa.NSStringPboardType]
+            pboard.declareTypes_owner_([Cocoa.NSStringPboardType], None)
+            pboard.setString_forType_(newString, Cocoa.NSStringPboardType)
             return ERROR(None)
         except:
             import traceback
