@@ -1,6 +1,5 @@
-from AppKit import *
 from PyObjCTools import AppHelper
-objc.setVerbose(1)
+import objc;objc.setVerbose(1)
 
 # Import all submodules,  to make sure all
 # classes are known to the runtime
