@@ -2,22 +2,23 @@
 """
 Find the library name for the current Python interpreter
 """
+from __future__ import print_function
 import sys
 import objc
-from Foundation import *
+from Foundation import NSBundle
 
 def S(*args):
-    return ''.join(args)
+    return b''.join(args)
 
 # these are void*
-NSSymbol = 'I'
-NSModule = 'I'
+NSSymbol = b'I'
+NSModule = b'I'
 
 FUNCTIONS=[
-    ( u'NSIsSymbolNameDefined', S(objc._C_BOOL, objc._C_CHARPTR) ),
-    ( u'NSLookupAndBindSymbol', S(NSSymbol, objc._C_CHARPTR) ),
-    ( u'NSModuleForSymbol', S(NSModule, NSSymbol) ),
-    ( u'NSLibraryNameForModule', S(objc._C_CHARPTR, NSModule) ),
+    ( 'NSIsSymbolNameDefined', S(objc._C_BOOL, objc._C_CHARPTR) ),
+    ( 'NSLookupAndBindSymbol', S(NSSymbol, objc._C_CHARPTR) ),
+    ( 'NSModuleForSymbol', S(NSModule, NSSymbol) ),
+    ( 'NSLibraryNameForModule', S(objc._C_CHARPTR, NSModule) ),
 ]
 
 def libraryNameForSymbol(symbol):
@@ -27,7 +28,7 @@ def libraryNameForSymbol(symbol):
     for (fn, sig) in FUNCTIONS:
         if fn not in d:
             raise ValueError("Couldn't find function %s" % (fn,))
-    symbol = '_' + symbol
+    symbol = b'_' + symbol
     if not d['NSIsSymbolNameDefined'](symbol):
         # symbol not defined
         return None
@@ -40,4 +41,4 @@ def libraryNameForSymbol(symbol):
     return d['NSLibraryNameForModule'](mod)
 
 if __name__ == "__main__":
-    print libraryNameForSymbol('Py_Initialize')
+    print(libraryNameForSymbol(b'Py_Initialize'))
