@@ -1,7 +1,7 @@
 from PyObjCTools import AppHelper
 
-from twisted.internet._threadedselect import install
-reactor = install()
+from twisted.internet import cfreactor
+cfreactor.install()
 
 
 # import classes required to start application
