@@ -4,11 +4,6 @@ from CoreFoundation import *
 from Foundation import NSDate
 
 
-try:
-    long
-except NameError:
-    long = int
-
 
 class TestDate (TestCase):
     def testTypes(self):
@@ -16,7 +11,11 @@ class TestDate (TestCase):
             cls = objc.lookUpClass('__NSDate')
             self.assertIs(cls, CFDateRef)
         except objc.error:
-            self.assertIsCFType(CFDateRef)
+            try:
+                cls = objc.lookUpClass('__NSCFDate')
+                self.assertIs(cls, CFDateRef)
+            except objc.error:
+                self.assertIsCFType(CFDateRef)
 
         try:
             cls = objc.lookUpClass('NSTimeZone')
