@@ -2,21 +2,6 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unichr
-except NameError:
-    unichr = chr
 
 
 class TestError (TestCase):
@@ -107,5 +92,9 @@ class TestError (TestCase):
         self.assertIsInstance(kCFErrorURLKey, unicode)
         self.assertIsInstance(kCFErrorFilePathKey, unicode)
 
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(kCFErrorLocalizedFailureKey, unicode)
+
 if __name__ == "__main__":
     main()
