@@ -5,11 +5,6 @@ FIXME: None of these tests actually use the filedescriptor
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
-try:
-    long
-except NameError:
-    long = int
-
 
 
 class TestFileDescriptor (TestCase):
