@@ -1,16 +1,6 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 
 class TestLocale (TestCase):
@@ -19,7 +9,11 @@ class TestLocale (TestCase):
             cls = objc.lookUpClass('__NSCFLocale')
             self.assertIs(CFLocaleRef, cls)
         except objc.error:
-            self.assertIsCFType(CFLocaleRef)
+            try:
+                cls = objc.lookUpClass('NSCFLocale')
+                self.assertIs(CFLocaleRef, cls)
+            except objc.error:
+                self.assertIsCFType(CFLocaleRef)
 
     def testGetTypeID(self):
         self.assertIsInstance(CFLocaleGetTypeID(), (int, long))
@@ -125,6 +119,11 @@ class TestLocale (TestCase):
         self.assertIsInstance(kCFIndianCalendar, unicode)
         self.assertIsInstance(kCFISO8601Calendar, unicode)
 
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(kCFIslamicTabularCalendar, unicode)
+        self.assertIsInstance(kCFIslamicUmmAlQuraCalendar, unicode)
+
     @min_os_level('10.6')
     def testFunctions10_6(self):
         v = CFLocaleGetWindowsLocaleCodeFromLocaleIdentifier('nl_NL')
@@ -140,6 +139,5 @@ class TestLocale (TestCase):
         v = CFLocaleGetLanguageLineDirection('NL')
         self.assertEqual(v, kCFLocaleLanguageDirectionTopToBottom)
 
-
 if __name__ == "__main__":
     main()
