@@ -1,16 +1,6 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 
 class TestNumberFormatter (TestCase):
@@ -36,9 +26,17 @@ class TestNumberFormatter (TestCase):
         v = CFNumberFormatterCreateStringWithNumber(None, fmt, 42.5)
         self.assertIsInstance(v, unicode)
         self.assertEqual(v , b'42.5'.decode('ascii'))
+
+        v = CFNumberFormatterCreateStringWithValue(None, fmt, kCFNumberDoubleType, 42.5)
+        self.assertIsInstance(v, unicode)
+        self.assertEqual(v , b'42.5'.decode('ascii'))
         num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, b"42.0a".decode('ascii'), (0, 5), 0)
         self.assertEqual(num , 42.0)
         self.assertEqual(rng , (0, 4))
+        ok, rng, num = CFNumberFormatterGetValueFromString(fmt, b"42.0a".decode('ascii'), (0, 5), kCFNumberDoubleType, None)
+        self.assertEqual(ok, True)
+        self.assertEqual(num , 42.0)
+        self.assertEqual(rng , (0, 4))
         num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, b"42.0a".decode('ascii'), (0, 5), kCFNumberFormatterParseIntegersOnly)
         self.assertEqual(num , 42)
         self.assertEqual(rng , (0, 2))
@@ -56,6 +54,7 @@ class TestNumberFormatter (TestCase):
         self.assertEqual(frac, 2)
         self.assertEqual(rnd, 0.0)
 
+
     def testConstants(self):
         self.assertEqual(kCFNumberFormatterNoStyle, 0)
         self.assertEqual(kCFNumberFormatterDecimalStyle, 1)
@@ -121,5 +120,12 @@ class TestNumberFormatter (TestCase):
         self.assertIsInstance(kCFNumberFormatterMinSignificantDigits, unicode)
         self.assertIsInstance(kCFNumberFormatterMaxSignificantDigits, unicode)
 
+    @min_os_level('10.11')
+    def testConstants(self):
+        self.assertEqual(kCFNumberFormatterOrdinalStyle, 6)
+        self.assertEqual(kCFNumberFormatterCurrencyISOCodeStyle, 8)
+        self.assertEqual(kCFNumberFormatterCurrencyPluralStyle, 9)
+        self.assertEqual(kCFNumberFormatterCurrencyAccountingStyle, 10)
+
 if __name__ == "__main__":
     main()
