@@ -5,16 +5,6 @@ import contextlib
 
 from .test_cfsocket import onTheNetwork
 
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 class TestStream (TestCase):
     def testTypes(self):
@@ -22,13 +12,21 @@ class TestStream (TestCase):
             if objc.lookUpClass('__NSCFInputStream') is not CFReadStreamRef:
                 self.assertIsCFType(CFReadStreamRef)
         except objc.error:
-            self.assertIsCFType(CFReadStreamRef)
+            try:
+                if objc.lookUpClass('NSCFInputStream') is not CFReadStreamRef:
+                    self.assertIsCFType(CFReadStreamRef)
+            except objc.error:
+                self.assertIsCFType(CFReadStreamRef)
 
         try:
             if objc.lookUpClass('__NSCFOutputStream') is not CFWriteStreamRef:
                 self.assertIsCFType(CFWriteStreamRef)
         except objc.error:
-            self.assertIsCFType(CFWriteStreamRef)
+            try:
+                if objc.lookUpClass('NSCFOutputStream') is not CFWriteStreamRef:
+                    self.assertIsCFType(CFWriteStreamRef)
+            except objc.error:
+                self.assertIsCFType(CFWriteStreamRef)
 
 
     def testConstants(self):
@@ -56,6 +54,24 @@ class TestStream (TestCase):
         self.assertIsInstance(kCFStreamPropertySocketRemoteHostName, unicode)
         self.assertIsInstance(kCFStreamPropertySocketRemotePortNumber, unicode)
 
+        self.assertIsInstance(kCFStreamErrorDomainSOCKS, (int, long))
+        self.assertIsInstance(kCFStreamPropertySOCKSProxy, unicode)
+        self.assertIsInstance(kCFStreamPropertySOCKSProxyHost, unicode)
+        self.assertIsInstance(kCFStreamPropertySOCKSProxyPort, unicode)
+        self.assertIsInstance(kCFStreamPropertySOCKSVersion, unicode)
+        self.assertIsInstance(kCFStreamSocketSOCKSVersion4, unicode)
+        self.assertIsInstance(kCFStreamSocketSOCKSVersion5, unicode)
+        self.assertIsInstance(kCFStreamPropertySOCKSUser, unicode)
+        self.assertIsInstance(kCFStreamPropertySOCKSPassword, unicode)
+        self.assertIsInstance(kCFStreamErrorDomainSSL, (int, long))
+        self.assertIsInstance(kCFStreamPropertySocketSecurityLevel, unicode)
+        self.assertIsInstance(kCFStreamSocketSecurityLevelNone, unicode)
+        self.assertIsInstance(kCFStreamSocketSecurityLevelSSLv2, unicode)
+        self.assertIsInstance(kCFStreamSocketSecurityLevelSSLv3, unicode)
+        self.assertIsInstance(kCFStreamSocketSecurityLevelTLSv1, unicode)
+        self.assertIsInstance(kCFStreamSocketSecurityLevelNegotiatedSSL, unicode)
+        self.assertIsInstance(kCFStreamPropertyShouldCloseNativeSocket, unicode)
+
     def testStructs(self):
         o = CFStreamError()
         self.assertHasAttr(o, 'domain')
@@ -276,7 +292,7 @@ class TestStream (TestCase):
 
         del readStream, writeStream
 
-    @onlyIf(onTheNetwork)
+    @onlyIf(onTheNetwork(), "Test requires a working Internet connection")
     def testSockets(self):
         with contextlib.closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as sd:
             sd.connect(('www.apple.com', 80))
@@ -424,5 +440,16 @@ class TestStream (TestCase):
         self.assertIs(state[0][2], data)
         self.assertEqual(state[0][1], kCFStreamEventCanAcceptBytes)
 
+    @min_os_level('10.9')
+    def testFunctions10_9(self):
+        CFReadStreamSetDispatchQueue # Nothing to test
+        CFWriteStreamSetDispatchQueue # Nothing to test
+        CFReadStreamCopyDispatchQueue # Nothing to test
+        CFWriteStreamCopyDispatchQueue # Nothing to test
+
+
+
+
+
 if __name__ == "__main__":
     main()
