@@ -4,16 +4,6 @@ from CoreFoundation import *
 import os
 from Foundation import NSURL
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 
 class TestURL (TestCase):
@@ -430,6 +420,7 @@ class TestURL (TestCase):
     @min_os_level('10.8')
     def testFunctions10_8(self):
         self.assertResultIsBOOL(CFURLStartAccessingSecurityScopedResource)
+        CFURLStopAccessingSecurityScopedResource
 
     @min_os_level('10.8')
     def testConstants10_8(self):
@@ -441,6 +432,28 @@ class TestURL (TestCase):
         self.assertEqual(kCFBookmarkResolutionWithoutMountingMask, 1 << 9)
         self.assertEqual(kCFURLBookmarkResolutionWithSecurityScope, 1 << 10)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertIsInstance(kCFURLTagNamesKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemDownloadingStatusKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemDownloadingErrorKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemUploadingErrorKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemDownloadingStatusNotDownloaded, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemDownloadingStatusDownloaded, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemDownloadingStatusCurrent, unicode)
+
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(kCFURLGenerationIdentifierKey, unicode)
+        self.assertIsInstance(kCFURLDocumentIdentifierKey, unicode)
+        self.assertIsInstance(kCFURLAddedToDirectoryDateKey, unicode)
+        self.assertIsInstance(kCFURLQuarantinePropertiesKey, unicode)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertIsInstance(kCFURLIsApplicationKey, unicode)
+        self.assertIsInstance(kCFURLApplicationIsScriptableKey, unicode)
+
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -492,8 +505,15 @@ class TestURL (TestCase):
         self.assertEqual(kCFBookmarkResolutionWithoutUIMask, 1<<8)
         self.assertEqual(kCFBookmarkResolutionWithoutMountingMask, 1<<9)
 
+        self.assertEqual(kCFURLBookmarkResolutionWithoutUIMask, 1<<8)
+        self.assertEqual(kCFURLBookmarkResolutionWithoutMountingMask, 1<<9)
+
     @min_os_level('10.7')
     def testConstants10_7(self):
+        self.assertEqual(kCFURLBookmarkCreationWithSecurityScope, 1<<11)
+        self.assertEqual(kCFURLBookmarkCreationSecurityScopeAllowOnlyReadAccess, 1<<12)
+        self.assertEqual(kCFURLBookmarkResolutionWithSecurityScope, 1<<10)
+
         self.assertIsInstance(kCFURLKeysOfUnsetValuesKey, unicode)
         self.assertIsInstance(kCFURLFileResourceIdentifierKey, unicode)
         self.assertIsInstance(kCFURLVolumeIdentifierKey, unicode)
@@ -541,5 +561,28 @@ class TestURL (TestCase):
         self.assertIsInstance(kCFURLUbiquitousItemPercentDownloadedKey, unicode)
         self.assertIsInstance(kCFURLUbiquitousItemPercentUploadedKey, unicode)
 
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(kCFURLVolumeLocalizedNameKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsEncryptedKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsRootFileSystemKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsCompressionKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsFileCloningKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsSwapRenamingKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsExclusiveRenamingKey, unicode)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(kCFURLVolumeAvailableCapacityForImportantUsageKey, unicode)
+        self.assertIsInstance(kCFURLVolumeAvailableCapacityForOpportunisticUsageKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsImmutableFilesKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsAccessPermissionsKey, unicode)
+
+    @min_os_level('10.9')
+    def testFunctions10_9(self):
+        self.assertResultIsBOOL(CFURLIsFileReferenceURL)
+
+
+
 if __name__ == "__main__":
     main()
