@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 import os
 
-try:
-    long
-except NameError:
-    long = int
-
 
 class TestCFURLEnumerator (TestCase):
 
@@ -26,7 +21,7 @@ class TestCFURLEnumerator (TestCase):
         self.assertIsInstance(ref, CFURLEnumeratorRef)
 
         ref = CFURLEnumeratorCreateForMountedVolumes(
-                None, kCFURLEnumeratorDefaultBehavior, [kCFURLNameKey])
+                None, kCFURLEnumeratorDefaultBehavior, None) #[kCFURLNameKey])
         self.assertIsInstance(ref, CFURLEnumeratorRef)
 
         self.assertArgIsOut(CFURLEnumeratorGetNextURL, 1)
