@@ -1,11 +1,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSAccessibilityHelper (NSObject):
     def accessibilityIsAttributeSettable_(self, arg):
         return 1
@@ -19,12 +14,44 @@ class TestNSAccessibilityHelper (NSObject):
     def accessibilitySetOverrideValue_forAttribute_(self, v, a):
         return 1
 
+    def accessibilityNotifiesWhenDestroyed(self): pass
+
+    def accessibilityIndexOfChild_(self, c): return 1
+    def accessibilityArrayAttributeCount_(self, c): return 1
+    def accessibilityArrayAttributeValues_index_maxCount_(self, v, i, c): return None
+
 class TestNSAccessibility (TestCase):
     def testInformal(self):
         self.assertResultIsBOOL(TestNSAccessibilityHelper.accessibilityIsAttributeSettable_)
         self.assertResultIsBOOL(TestNSAccessibilityHelper.accessibilityIsIgnored)
         self.assertArgHasType(TestNSAccessibilityHelper.accessibilityHitTest_, 0, NSPoint.__typestr__)
         self.assertResultIsBOOL(TestNSAccessibilityHelper.accessibilitySetOverrideValue_forAttribute_)
+        self.assertResultIsBOOL(TestNSAccessibilityHelper.accessibilityNotifiesWhenDestroyed)
+        self.assertResultHasType(TestNSAccessibilityHelper.accessibilityIndexOfChild_, objc._C_NSUInteger)
+        self.assertResultHasType(TestNSAccessibilityHelper.accessibilityArrayAttributeCount_, objc._C_NSUInteger)
+        self.assertResultHasType(TestNSAccessibilityHelper.accessibilityArrayAttributeCount_, objc._C_NSUInteger)
+        self.assertArgHasType(TestNSAccessibilityHelper.accessibilityArrayAttributeValues_index_maxCount_, 1, objc._C_NSUInteger)
+        self.assertArgHasType(TestNSAccessibilityHelper.accessibilityArrayAttributeValues_index_maxCount_, 2, objc._C_NSUInteger)
+
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(NSWorkspace.accessibilityDisplayShouldIncreaseContrast)
+        self.assertResultIsBOOL(NSWorkspace.accessibilityDisplayShouldDifferentiateWithoutColor)
+        self.assertResultIsBOOL(NSWorkspace.accessibilityDisplayShouldReduceTransparency)
+
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSWorkspace.accessibilityDisplayShouldReduceMotion)
+        self.assertResultIsBOOL(NSWorkspace.accessibilityDisplayShouldInvertColors)
+
+    @min_os_level('10.10')
+    def testFunctions10_10(self):
+        NSAccessibilityFrameInView # Existence
+        NSAccessibilityPointInView # Existence
+
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(NSWorkspaceAccessibilityDisplayOptionsDidChangeNotification, unicode)
 
     def testFunction(self):
         v = NSAccessibilityRoleDescription(NSAccessibilityButtonRole, None)
@@ -54,7 +81,12 @@ class TestNSAccessibility (TestCase):
         v = NSAccessibilityPostNotification(b, "hello")
         self.assertIs(v, None)
 
+
     def testConstants(self):
+        self.assertEqual(NSAccessibilityAnnotationPositionFullRange, 0)
+        self.assertEqual(NSAccessibilityAnnotationPositionStart, 1)
+        self.assertEqual(NSAccessibilityAnnotationPositionEnd, 2)
+
         self.assertIsInstance(NSAccessibilityErrorCodeExceptionInfo, unicode)
         self.assertIsInstance(NSAccessibilityRoleAttribute, unicode)
         self.assertIsInstance(NSAccessibilityRoleDescriptionAttribute, unicode)
@@ -130,6 +162,7 @@ class TestNSAccessibility (TestCase):
         self.assertIsInstance(NSAccessibilityAttachmentTextAttribute, unicode)
         self.assertIsInstance(NSAccessibilityLinkTextAttribute, unicode)
         self.assertIsInstance(NSAccessibilityMisspelledTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityMarkedMisspelledTextAttribute, unicode)
         self.assertIsInstance(NSAccessibilityFontNameKey, unicode)
         self.assertIsInstance(NSAccessibilityFontFamilyKey, unicode)
         self.assertIsInstance(NSAccessibilityVisibleNameKey, unicode)
@@ -306,10 +339,10 @@ class TestNSAccessibility (TestCase):
 
     @min_os_level('10.6')
     def testConstants10_6(self):
+        self.assertIsInstance(NSAccessibilityUnknownOrientationValue, unicode)
         self.assertIsInstance(NSAccessibilityWarningValueAttribute, unicode)
         self.assertIsInstance(NSAccessibilityCriticalValueAttribute, unicode)
         self.assertIsInstance(NSAccessibilityPlaceholderValueAttribute, unicode)
-        self.assertIsInstance(NSAccessibilityUnknownOrientationValue, unicode)
         self.assertIsInstance(NSAccessibilitySelectedCellsAttribute, unicode)
         self.assertIsInstance(NSAccessibilityVisibleCellsAttribute, unicode)
         self.assertIsInstance(NSAccessibilityRowHeaderUIElementsAttribute, unicode)
@@ -348,10 +381,94 @@ class TestNSAccessibility (TestCase):
         self.assertIsInstance(NSAccessibilityFullScreenButtonAttribute, unicode)
         self.assertIsInstance(NSAccessibilityPopoverRole, unicode)
         self.assertIsInstance(NSAccessibilityFullScreenButtonSubrole, unicode)
+        self.assertIsInstance(NSAccessibilityIdentifierAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityAnnouncementRequestedNotification, unicode)
+        self.assertIsInstance(NSAccessibilityAnnouncementKey, unicode)
 
     @min_os_level('10.8')
     def testConstants10_8(self):
         self.assertIsInstance(NSAccessibilityExtrasMenuBarAttribute, unicode)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertIsInstance(NSAccessibilityContainsProtectedContentAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityShowAlternateUIAction, unicode)
+        self.assertIsInstance(NSAccessibilityShowDefaultUIAction, unicode)
+        self.assertIsInstance(NSAccessibilityLayoutChangedNotification, unicode)
+        self.assertIsInstance(NSAccessibilityToggleSubrole, unicode)
+        self.assertIsInstance(NSAccessibilitySwitchSubrole, unicode)
+        self.assertIsInstance(NSAccessibilityDescriptionListSubrole, unicode)
+        self.assertIsInstance(NSAccessibilityUIElementsKey, unicode)
+        self.assertIsInstance(NSAccessibilityPriorityKey, unicode)
+
+        self.assertEqual(NSAccessibilityPriorityLow, 10)
+        self.assertEqual(NSAccessibilityPriorityMedium, 50)
+        self.assertEqual(NSAccessibilityPriorityHigh, 90)
+
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(NSAccessibilityActivationPointAttribute, unicode)
+
+        self.assertIsInstance(NSAccessibilitySharedFocusElementsAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityAlternateUIVisibleAttribute, unicode)
+
+        self.assertEqual(NSAccessibilityOrientationUnknown, 0)
+        self.assertEqual(NSAccessibilityOrientationVertical, 1)
+        self.assertEqual(NSAccessibilityOrientationHorizontal, 2)
+
+        self.assertEqual(NSAccessibilitySortDirectionUnknown, 0)
+        self.assertEqual(NSAccessibilitySortDirectionAscending, 1)
+        self.assertEqual(NSAccessibilitySortDirectionDescending, 2)
+
+        self.assertEqual(NSAccessibilityRulerMarkerTypeUnknown, 0)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeTabStopLeft, 1)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeTabStopRight, 2)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeTabStopCenter, 3)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeTabStopDecimal, 4)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeIndentHead, 5)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeIndentTail, 6)
+        self.assertEqual(NSAccessibilityRulerMarkerTypeIndentFirstLine, 7)
+
+        self.assertEqual(NSAccessibilityUnitsUnknown, 0)
+        self.assertEqual(NSAccessibilityUnitsInches, 1)
+        self.assertEqual(NSAccessibilityUnitsCentimeters, 2)
+        self.assertEqual(NSAccessibilityUnitsPoints, 3)
+        self.assertEqual(NSAccessibilityUnitsPicas, 4)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertIsInstance(NSAccessibilityListItemPrefixTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityListItemIndexTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityListItemLevelTextAttribute, unicode)
+
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(NSAccessibilityRequiredAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityMenuBarItemRole, unicode)
+        self.assertIsInstance(NSAccessibilityTextAlignmentAttribute, unicode)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(NSAccessibilityAnnotationLabel, unicode)
+        self.assertIsInstance(NSAccessibilityAnnotationElement, unicode)
+        self.assertIsInstance(NSAccessibilityAnnotationLocation, unicode)
+
+        self.assertIsInstance(NSAccessibilityLanguageTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityCustomTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityAnnotationTextAttribute, unicode)
+        self.assertIsInstance(NSAccessibilityPageRole, unicode)
+        self.assertIsInstance(NSAccessibilityTabButtonSubrole, unicode)
+        self.assertIsInstance(NSAccessibilityCollectionListSubrole, unicode)
+        self.assertIsInstance(NSAccessibilitySectionListSubrole, unicode)
+
+    @min_os_level('10.7')
+    def testFunctions10_7(self):
+        self.assertIsInstance(NSAccessibilityPostNotificationWithUserInfo, objc.function)
+
+    @min_os_level('10.9')
+    def testFunctions10_9(self):
+        self.assertArgIsBOOL(NSAccessibilitySetMayContainProtectedContent, 0)
+        self.assertResultIsBOOL(NSAccessibilitySetMayContainProtectedContent)
+
 if __name__ == "__main__":
     main()
