@@ -4,27 +4,17 @@ from Foundation import *
 from AppKit import *
 import Foundation
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 class TestNSAttributedString (TestCase):
-    def testOutput(self):
+    def testMethodsFoundation(self):
         self.assertArgIsOut(NSAttributedString.attributesAtIndex_effectiveRange_, 1)
-        self.assertArgIsOut(NSAttributedString.attribute_atIndex_effectiveRange_, 2)
         self.assertArgIsOut(NSAttributedString.attributesAtIndex_longestEffectiveRange_inRange_, 1)
         self.assertArgIsOut(NSAttributedString.attribute_atIndex_longestEffectiveRange_inRange_, 2)
 
         self.assertResultIsBOOL(NSAttributedString.isEqualToAttributedString_)
 
     def testConstantsAppKit(self):
+        self.assertIsInstance(NSManagerDocumentAttribute, unicode)
         self.assertIsInstance(NSFontAttributeName, unicode)
         self.assertIsInstance(NSParagraphStyleAttributeName, unicode)
         self.assertIsInstance(NSForegroundColorAttributeName, unicode)
@@ -61,6 +51,8 @@ class TestNSAttributedString (TestCase):
         self.assertEqual(NSUnderlinePatternDashDot, 0x0300)
         self.assertEqual(NSUnderlinePatternDashDotDot, 0x0400)
 
+        self.assertIsInstance(NSUnderlineByWordMask, (int, long))
+
         self.assertEqual(NSSpellingStateSpellingFlag, 1)
         self.assertEqual(NSSpellingStateGrammarFlag, 2)
 
@@ -171,6 +163,16 @@ class TestNSAttributedString (TestCase):
         self.assertIsInstance(NSTextLayoutSectionRange, unicode)
         self.assertIsInstance(NSTextLayoutSectionsAttribute, unicode)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(NSTextAlternativesAttributeName, unicode)
+        self.assertIsInstance(NSUsesScreenFontsDocumentAttribute, unicode)
+
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(NSTextEffectAttributeName, unicode)
+        self.assertIsInstance(NSTextEffectLetterpressStyle, unicode)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertArgHasType(NSAttributedString.enumerateAttributesInRange_options_usingBlock_, 0, NSRange.__typestr__)
