@@ -8,24 +8,24 @@ from AppKit import *
 class TestNSBezierPath(TestCase):
     if not hasattr(TestCase, 'assertAlmostEquals'):
         def assertAlmostEquals(self, val1, val2):
-            self.assert_(abs(val1 - val2) < 0.000001)
+            self.assertTrue(abs(val1 - val2) < 0.000001)
 
     def assertPointEquals(self, point1, point2):
-        self.assertAlmostEquals(point1[0], point2[0])
-        self.assertAlmostEquals(point1[1], point2[1])
+        self.assertAlmostEqual(point1[0], point2[0])
+        self.assertAlmostEqual(point1[1], point2[1])
 
     def test_creation(self):
         p = NSBezierPath.bezierPath()
-        self.assert_(p is not None)
+        self.assertIsNot(p, None)
         self.assertEqual(p.elementCount(), 0)
 
         p = NSBezierPath.bezierPathWithOvalInRect_(((0, 0), (100, 50)))
-        self.assert_(p is not None)
+        self.assertIsNot(p, None)
         self.assertEqual(p.elementCount(), 5)
 
     def test_appendPoints(self):
         p = NSBezierPath.bezierPath()
-        self.assert_(p is not None)
+        self.assertIsNot(p, None)
         self.assertEqual(p.elementCount(), 0)
 
         points = [ (0, 0), (100, 0), (100, 100), (0, 0) ]
@@ -40,15 +40,15 @@ class TestNSBezierPath(TestCase):
         #self.assertEqual(pattern, None)
         self.assertEqual(pattern, objc.NULL)
         self.assertEqual(count, 4)
-        self.assertAlmostEquals(phase, 45.0)
+        self.assertAlmostEqual(phase, 45.0)
 
         pattern, count, phase = p.getLineDash_count_phase_(None, 4, None)
-        self.assertAlmostEquals(pattern[0], 10)
-        self.assertAlmostEquals(pattern[1], 10)
-        self.assertAlmostEquals(pattern[2], 20)
-        self.assertAlmostEquals(pattern[3], 5)
+        self.assertAlmostEqual(pattern[0], 10)
+        self.assertAlmostEqual(pattern[1], 10)
+        self.assertAlmostEqual(pattern[2], 20)
+        self.assertAlmostEqual(pattern[3], 5)
         self.assertEqual(count, 4)
-        self.assertAlmostEquals(phase, 45.0)
+        self.assertAlmostEqual(phase, 45.0)
 
     def test_elementAtIndex(self):
         p = NSBezierPath.bezierPath()
@@ -117,22 +117,47 @@ class TestNSBezierPath(TestCase):
         self.assertEqual(NSButtLineCapStyle, 0)
         self.assertEqual(NSRoundLineCapStyle, 1)
         self.assertEqual(NSSquareLineCapStyle, 2)
+
         self.assertEqual(NSMiterLineJoinStyle, 0)
         self.assertEqual(NSRoundLineJoinStyle, 1)
         self.assertEqual(NSBevelLineJoinStyle, 2)
+
         self.assertEqual(NSNonZeroWindingRule, 0)
         self.assertEqual(NSEvenOddWindingRule, 1)
+
         self.assertEqual(NSMoveToBezierPathElement, 0)
         self.assertEqual(NSLineToBezierPathElement, 1)
         self.assertEqual(NSCurveToBezierPathElement, 2)
         self.assertEqual(NSClosePathBezierPathElement, 3)
 
+        self.assertEqual(NSLineCapStyleButt, 0)
+        self.assertEqual(NSLineCapStyleRound, 1)
+        self.assertEqual(NSLineCapStyleSquare, 2)
+
+        self.assertEqual(NSLineJoinStyleMiter, 0)
+        self.assertEqual(NSLineJoinStyleRound, 1)
+        self.assertEqual(NSLineJoinStyleBevel, 2)
+
+        self.assertEqual(NSWindingRuleNonZero, 0)
+        self.assertEqual(NSWindingRuleEvenOdd, 1)
+
+        self.assertEqual(NSBezierPathElementMoveTo, 0)
+        self.assertEqual(NSBezierPathElementLineTo, 1)
+        self.assertEqual(NSBezierPathElementCurveTo, 2)
+        self.assertEqual(NSBezierPathElementClosePath, 3)
+
 
     def testMethods(self):
         self.assertResultIsBOOL(NSBezierPath.isEmpty)
         self.assertResultIsBOOL(NSBezierPath.containsPoint_)
         self.assertResultIsBOOL(NSBezierPath.cachesBezierPath)
         self.assertArgIsBOOL(NSBezierPath.setCachesBezierPath_, 0)
+        self.assertArgIsBOOL(NSBezierPath.appendBezierPathWithArcWithCenter_radius_startAngle_endAngle_clockwise_, 4)
+
+        self.assertArgSizeInArg(NSBezierPath.appendBezierPathWithGlyphs_count_inFont_, 0, 1)
+
+        # XXX: NSBezierPath.drawPackedGlyphs_atPoint_
+        # XXX: NSBezierPath.appendBezierPathWithPackedGlyphs_
 
 
 if __name__ == '__main__':
