@@ -6,16 +6,16 @@ class TestNSBitmapImageRep (TestCase):
     def test_getTIFFCompressionTypes(self):
         r = AppKit.NSBitmapImageRep.getTIFFCompressionTypes_count_(None, None)
 
-        self.assert_(isinstance(r, tuple))
+        self.assertIsInstance(r, tuple)
         self.assertEqual(len(r), 2)
 
         lst, ln = r
 
-        self.assert_(isinstance(lst, tuple))
-        self.assert_(isinstance(ln, int))
+        self.assertIsInstance(lst, tuple)
+        self.assertIsInstance(ln, int)
 
         self.assertEqual(len(lst), ln)
-        self.assert_(reduce(lambda x, y: x and isinstance(x, int), lst, True))
+        self.assertTrue(all(isinstance(x, int) for x in lst))
 
 if __name__ == "__main__":
     main()
