@@ -6,16 +6,6 @@ import sys
 from objc import YES, NO
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 class TestNSBitmapImageRep(TestCase):
     def testInstantiation(self):
@@ -177,18 +167,37 @@ class TestBadCreation(TestCase):
         self.assertEqual(NSTIFFCompressionNEXT, 32766)
         self.assertEqual(NSTIFFCompressionPackBits, 32773)
         self.assertEqual(NSTIFFCompressionOldJPEG, 32865)
+
         self.assertEqual(NSTIFFFileType, 0)
         self.assertEqual(NSBMPFileType, 1)
         self.assertEqual(NSGIFFileType, 2)
         self.assertEqual(NSJPEGFileType, 3)
         self.assertEqual(NSPNGFileType, 4)
         self.assertEqual(NSJPEG2000FileType, 5)
+
+        self.assertEqual(NSBitmapImageFileTypeTIFF, 0)
+        self.assertEqual(NSBitmapImageFileTypeBMP, 1)
+        self.assertEqual(NSBitmapImageFileTypeGIF, 2)
+        self.assertEqual(NSBitmapImageFileTypeJPEG, 3)
+        self.assertEqual(NSBitmapImageFileTypePNG, 4)
+        self.assertEqual(NSBitmapImageFileTypeJPEG2000, 5)
+
+        self.assertEqual(NSBitmapFormatAlphaFirst, 1 << 0)
+        self.assertEqual(NSBitmapFormatAlphaNonpremultiplied, 1 << 1)
+        self.assertEqual(NSBitmapFormatFloatingPointSamples, 1 << 2)
+        self.assertEqual(NSBitmapFormatSixteenBitLittleEndian, 1 << 8)
+        self.assertEqual(NSBitmapFormatThirtyTwoBitLittleEndian, 1 << 9)
+        self.assertEqual(NSBitmapFormatSixteenBitBigEndian, 1 << 10)
+        self.assertEqual(NSBitmapFormatThirtyTwoBitBigEndian, 1 << 11)
+
+
         self.assertEqual(NSImageRepLoadStatusUnknownType, -1)
         self.assertEqual(NSImageRepLoadStatusReadingHeader, -2)
         self.assertEqual(NSImageRepLoadStatusWillNeedAllData, -3)
         self.assertEqual(NSImageRepLoadStatusInvalidData, -4)
         self.assertEqual(NSImageRepLoadStatusUnexpectedEOF, -5)
         self.assertEqual(NSImageRepLoadStatusCompleted, -6)
+
         self.assertEqual(NSAlphaFirstBitmapFormat, 1 << 0)
         self.assertEqual(NSAlphaNonpremultipliedBitmapFormat, 1 << 1)
         self.assertEqual(NSFloatingPointSamplesBitmapFormat, 1 << 2)
@@ -208,6 +217,14 @@ class TestBadCreation(TestCase):
         self.assertIsInstance(NSImageEXIFData, unicode)
         self.assertIsInstance(NSImageFallbackBackgroundColor, unicode)
 
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertEqual(NS16BitLittleEndianBitmapFormat, (1 << 8))
+        self.assertEqual(NS32BitLittleEndianBitmapFormat, (1 << 9))
+        self.assertEqual(NS16BitBigEndianBitmapFormat, (1 << 10))
+        self.assertEqual(NS32BitBigEndianBitmapFormat, (1 << 11))
+
+
     def testTiffCompression(self):
         lst, nr = NSBitmapImageRep.getTIFFCompressionTypes_count_(None, None)
         self.assertIsInstance(lst, tuple)
@@ -225,6 +242,5 @@ class TestBadCreation(TestCase):
         self.assertArgIsOut(NSBitmapImageRep.getCompression_factor_, 1)
 
 
-
 if __name__ == '__main__':
     main( )
