@@ -47,6 +47,10 @@ class TestNSData(TestCase):
         self.assertArgIsOut(NSData.dataWithContentsOfURL_options_error_, 2)
         self.assertArgIsOut(NSData.initWithContentsOfFile_options_error_, 2)
         self.assertArgIsOut(NSData.initWithContentsOfURL_options_error_, 2)
+        self.assertArgIsIn(NSData.dataWithBytesNoCopy_length_, 0)
+        self.assertArgSizeInArg(NSData.dataWithBytes_length_, 0, 1)
+        self.assertArgIsIn(NSData.initWithBytesNoCopy_length_, 0)
+        self.assertArgSizeInArg(NSData.initWithBytes_length_, 0, 1)
 
     def testConstants(self):
         self.assertEqual(NSMappedRead, 1)
@@ -66,15 +70,43 @@ class TestNSData(TestCase):
     def testConstants10_7(self):
         self.assertEqual(NSDataReadingMappedAlways, 1<<3)
 
+        self.assertEqual(NSDataReadingMappedIfSafe, 1<<0)
+        self.assertEqual(NSDataReadingUncached, 1<<1)
+
     @min_os_level('10.8')
     def testConstants10_8(self):
         self.assertEqual(NSDataWritingWithoutOverwriting, 1<<1)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertEqual(NSDataBase64Encoding64CharacterLineLength, 1<<0)
+        self.assertEqual(NSDataBase64Encoding76CharacterLineLength, 1<<1)
+        self.assertEqual(NSDataBase64EncodingEndLineWithCarriageReturn, 1<<4)
+        self.assertEqual(NSDataBase64EncodingEndLineWithLineFeed, 1<<5)
+
+        self.assertEqual(NSDataBase64DecodingIgnoreUnknownCharacters, 1<<0)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertResultHasType(NSData.rangeOfData_options_range_, NSRange.__typestr__)
         self.assertArgHasType(NSData.rangeOfData_options_range_, 2, NSRange.__typestr__)
 
+    @min_os_level('10.9')
+    def testMethods10_6(self):
+        self.assertArgIsBlock(NSData.enumerateByteRangesUsingBlock_, 0, b'vn^v' + NSRange.__typestr__ + b'o^Z')
+        data = NSData.dataWithBytes_length_(rawBytes, len(rawBytes))
+
+        l = []
+        def cb (buf, rng, done):
+            l.append((buf, rng, done))
+            return False
+        data.enumerateByteRangesUsingBlock_(cb)
+        self.assertEqual(l, [
+            (rawBytes, NSRange(0, len(rawBytes)), None),
+        ])
+
+        self.assertArgIsBlock(NSData.initWithBytesNoCopy_length_deallocator_, 2, b'vn^v' + objc._C_NSUInteger)
+
     def assertDataContents(self, d1, d2, rawData):
         self.assertEqual(len(d1), d1.length(), "d1: len() and -length didn't match.")
         self.assertEqual(len(d1), len(rawData), "d1: len(<data>) and len(<input>) didn't match. %d vs %d"%(len(d1), len(rawData)))
@@ -294,10 +326,12 @@ class TestMyData (TestCase):
 import array
 class TestBuffer(TestCase):
     def testArray(self):
+        pool = NSAutoreleasePool.alloc().init()
         a = array.array('b', b'foo')
         m = NSMutableData.dataWithData_(a)
         self.assertEqual(array_tobytes(a), m[:])
         self.assertTrue(objc.repythonify(a) is a)
+        del pool
         array_frombytes(a, m)
         self.assertEqual(array_tobytes(a), b'foofoo')
         m.appendData_(a)
