@@ -12,8 +12,10 @@ class TestNSDatePickerCell (TestCase):
         self.assertEqual(NSTextFieldAndStepperDatePickerStyle, 0)
         self.assertEqual(NSClockAndCalendarDatePickerStyle, 1)
         self.assertEqual(NSTextFieldDatePickerStyle, 2)
+
         self.assertEqual(NSSingleDateMode, 0)
         self.assertEqual(NSRangeDateMode, 1)
+
         self.assertEqual(NSHourMinuteDatePickerElementFlag, 0x000c)
         self.assertEqual(NSHourMinuteSecondDatePickerElementFlag, 0x000e)
         self.assertEqual(NSTimeZoneDatePickerElementFlag, 0x0010)
@@ -21,6 +23,22 @@ class TestNSDatePickerCell (TestCase):
         self.assertEqual(NSYearMonthDayDatePickerElementFlag, 0x00e0)
         self.assertEqual(NSEraDatePickerElementFlag, 0x0100)
 
+        self.assertEqual(NSDatePickerStyleTextFieldAndStepper, 0)
+        self.assertEqual(NSDatePickerStyleClockAndCalendar, 1)
+        self.assertEqual(NSDatePickerStyleTextField, 2)
+
+        self.assertEqual(NSDatePickerModeSingle, 0)
+        self.assertEqual(NSDatePickerModeRange, 1)
+
+        self.assertEqual(NSDatePickerElementFlagHourMinute, 0x000c)
+        self.assertEqual(NSDatePickerElementFlagHourMinuteSecond, 0x000e)
+        self.assertEqual(NSDatePickerElementFlagTimeZone, 0x0010)
+
+        self.assertEqual(NSDatePickerElementFlagYearMonth, 0x00c0)
+        self.assertEqual(NSDatePickerElementFlagYearMonthDay, 0x00e0)
+        self.assertEqual(NSDatePickerElementFlagEra, 0x0100)
+
+
     def testMethods(self):
         o = TestNSDatePickerHelper.alloc().init()
         m = o.datePickerCell_validateProposedDateValue_timeInterval_.__metadata__()
@@ -30,5 +48,9 @@ class TestNSDatePickerCell (TestCase):
         self.assertResultIsBOOL(NSDatePickerCell.drawsBackground)
         self.assertArgIsBOOL(NSDatePickerCell.setDrawsBackground_, 0)
 
+    @min_sdk_level('10.10')
+    def testProtocols(self):
+        objc.protocolNamed('NSDatePickerCellDelegate')
+
 if __name__ == "__main__":
     main()
