@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 class TestNSDistributedNotificationCenter (TestCase):
     def testConstants(self):
@@ -19,6 +14,9 @@ class TestNSDistributedNotificationCenter (TestCase):
         self.assertEqual(NSNotificationDeliverImmediately, 1)
         self.assertEqual(NSNotificationPostToAllSessions, 2)
 
+        self.assertEqual(NSDistributedNotificationDeliverImmediately, 1)
+        self.assertEqual(NSDistributedNotificationPostToAllSessions, 2)
+
     def testMethods(self):
         self.assertArgIsSEL(NSDistributedNotificationCenter.addObserver_selector_name_object_suspensionBehavior_, 1, b'v@:@')
         self.assertArgIsSEL(NSDistributedNotificationCenter.addObserver_selector_name_object_, 1, b'v@:@')
