@@ -129,6 +129,8 @@ class TestNSDocument (TestCase):
         self.assertArgIsOut(NSDocument.duplicateAndReturnError_, 0)
         self.assertResultIsBOOL(NSDocument.isInViewingMode)
 
+        self.assertArgIsBlock(NSDocument.saveToURL_ofType_forSaveOperation_completionHandler_, 3, b'v@')
+
     @min_os_level('10.8')
     def testMethods10_8(self):
         self.assertArgIsBOOL(NSDocument.setDraft_, 0)
@@ -150,5 +152,16 @@ class TestNSDocument (TestCase):
         self.assertResultIsBOOL(NSDocument.isLocked)
         self.assertResultIsBOOL(NSDocument.usesUbiquitousStorage)
 
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSDocument.isBrowsingVersions)
+
+        self.assertArgIsBlock(NSDocument.stopBrowsingVersionsWithCompletionHandler_, 0, b'v')
+
+    @min_os_level('10.13')
+    def testMethods10_13(self):
+        self.assertResultIsBOOL(NSDocument.allowsDocumentSharing)
+        self.assertArgIsBlock(NSDocument.shareDocumentWithSharingService_completionHandler_, 1, b'vZ')
+
 if __name__ == "__main__":
     main()
