@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSDrawerHelper (NSObject):
     def drawerShouldOpen_(self, sender): return 1
     def drawerShouldClose_(self, sender): return 1
@@ -27,13 +22,15 @@ class TestNSDrawer (TestCase):
     def testMethods(self):
         self.assertArgHasType(NSDrawer.setMinContentSize_, 0, NSSize.__typestr__)
 
+    @min_sdk_level('10.10')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSDrawerDelegate')
+
     def testProtocols(self):
         self.assertResultIsBOOL(TestNSDrawerHelper.drawerShouldOpen_)
         self.assertResultIsBOOL(TestNSDrawerHelper.drawerShouldClose_)
         self.assertResultHasType(TestNSDrawerHelper.drawerWillResizeContents_toSize_, NSSize.__typestr__)
         self.assertArgHasType(TestNSDrawerHelper.drawerWillResizeContents_toSize_, 1, NSSize.__typestr__)
 
-
-
 if __name__ == "__main__":
     main()
