@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSFileManagerHelper (NSObject):
     def fileManager_shouldProceedAfterError_(self, a, b): return 1
     def fileManager_willProcessPath_(self, a, b): pass
@@ -81,6 +76,19 @@ class TestNSFileManager (TestCase):
     def testConstants10_8(self):
         self.assertIsInstance(NSUbiquityIdentityDidChangeNotification, unicode)
 
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertEqual(NSURLRelationshipContains, 0)
+        self.assertEqual(NSURLRelationshipSame, 1)
+        self.assertEqual(NSURLRelationshipOther, 2)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertEqual(NSFileManagerUnmountAllPartitionsAndEjectDisk, 1<<0)
+        self.assertEqual(NSFileManagerUnmountWithoutUI, 1<<1)
+
+        self.assertIsInstance(NSFileManagerUnmountDissentingProcessIdentifierErrorKey, unicode)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertArgIsOut(NSFileManager.contentsOfDirectoryAtURL_includingPropertiesForKeys_options_error_, 3)
@@ -132,6 +140,16 @@ class TestNSFileManager (TestCase):
         self.assertArgIsOut(NSFileManager.trashItemAtURL_resultingItemURL_error_, 1)
         self.assertArgIsOut(NSFileManager.trashItemAtURL_resultingItemURL_error_, 2)
 
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(NSFileManager.getRelationship_ofDirectoryAtURL_toItemAtURL_error_)
+        self.assertArgIsOut(NSFileManager.getRelationship_ofDirectoryAtURL_toItemAtURL_error_, 0)
+        self.assertArgIsOut(NSFileManager.getRelationship_ofDirectoryAtURL_toItemAtURL_error_, 3)
+
+        self.assertResultIsBOOL(NSFileManager.getRelationship_ofDirectory_inDomain_toItemAtURL_error_)
+        self.assertArgIsOut(NSFileManager.getRelationship_ofDirectory_inDomain_toItemAtURL_error_, 0)
+        self.assertArgIsOut(NSFileManager.getRelationship_ofDirectory_inDomain_toItemAtURL_error_, 4)
+
     def testOutput(self):
         obj = NSFileManager.defaultManager()
         m = obj.setAttributes_ofItemAtPath_error_.__metadata__()
@@ -218,6 +236,7 @@ class TestNSFileManager (TestCase):
         self.assertEqual(m['retval']['type'] , 'Z')
         m = obj.fileManager_shouldProceedAfterError_removingItemAtPath_.__metadata__()
         self.assertEqual(m['retval']['type'] , 'Z')
+
     @min_os_level('10.5')
     def testMethods10_5(self):
         self.assertResultIsBOOL(NSFileManager.setAttributes_ofItemAtPath_error_)
@@ -275,6 +294,14 @@ class TestNSFileManager (TestCase):
         self.assertResultIsBOOL(NSDictionary.fileIsAppendOnly)
         self.assertResultIsBOOL(NSDictionary.fileExtensionHidden)
 
+    @min_os_level('10.11')
+    def testMethods10_11(self):
+        self.assertArgIsBlock(NSFileManager.unmountVolumeAtURL_options_completionHandler_, 2, b'v@')
+
+    @min_os_level('10.13')
+    def testMethods10_13(self):
+        self.assertArgIsBlock(NSFileManager.getFileProviderMessageInterfacesForItemAtURL_completionHandler_, 1, b'v@@')
+
     def testProtocols(self):
         self.assertResultIsBOOL(TestNSFileManagerHelper.fileManager_shouldProceedAfterError_)
         self.assertResultIsBOOL(TestNSFileManagerHelper.fileManager_shouldCopyItemAtPath_toPath_)
@@ -298,5 +325,9 @@ class TestNSFileManager (TestCase):
         self.assertResultIsBOOL(TestNSFileManagerHelper.fileManager_shouldRemoveItemAtURL_)
         self.assertResultIsBOOL(TestNSFileManagerHelper.fileManager_shouldProceedAfterError_removingItemAtURL_)
 
+    @min_sdk_level('10.10')
+    def testProtocols10_10(self):
+        objc.protocolNamed('NSFileManagerDelegate')
+
 if __name__ == '__main__':
     main()
