@@ -6,16 +6,6 @@ from AppKit import *
 
 import os
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 class TestNSFont(TestCase):
     def matrixEquals(self, value1, value2):
@@ -28,17 +18,17 @@ class TestNSFont(TestCase):
     def testMatrixMethods(self):
         o = AppKit.NSFont.boldSystemFontOfSize_(10);
         m = o.matrix()
-        self.assert_(isinstance(m, tuple))
+        self.assertTrue(isinstance(m, tuple))
         self.assertEqual(len(m), 6)
 
         nm = o.fontName()
 
         o = AppKit.NSFont.fontWithName_matrix_(
                 nm, AppKit.NSFontIdentityMatrix)
-        self.assert_(o is not None)
+        self.assertTrue(o is not None)
 
         m = o.matrix()
-        self.assert_(isinstance(m, tuple))
+        self.assertIsInstance(m, tuple)
         self.assertEqual(len(m), 6)
 
         self.matrixEquals(m, (1.0, 0.0, 0.0, 1.0, 0.0, 0.0))
@@ -47,10 +37,10 @@ class TestNSFont(TestCase):
         # same thing happens in pure ObjC code.
         #o = AppKit.NSFont.fontWithName_matrix_(nm, (1.0, 2.0, 3.0, 4.0, 5.0, 6.0))
         o = AppKit.NSFont.fontWithName_matrix_(nm, (12.0, 0.0, 0.0, 12.0, 0.0, 0.0))
-        self.assert_(o is not None)
+        self.assertTrue(o is not None)
 
         m = o.matrix()
-        self.assert_(isinstance(m, tuple))
+        self.assertIsInstance(m, tuple)
         self.assertEqual(len(m), 6)
 
         #self.matrixEquals(m, (1.0, 2.0, 3.0, 4.0, 5.0, 6.0))
@@ -105,7 +95,17 @@ class TestNSFont(TestCase):
         self.assertIsInstance(NSAFMItalicAngle, unicode)
         self.assertIsInstance(NSAFMMappingScheme, unicode)
 
+    @min_os_level('10.13')
+    def testMethods10_13(self):
+        self.assertArgIsOut(NSFont.getBoundingRects_forCGGlyphs_count_, 0)
+        self.assertArgIsIn(NSFont.getBoundingRects_forCGGlyphs_count_, 1)
+        self.assertArgSizeInArg(NSFont.getBoundingRects_forCGGlyphs_count_, 0, 2)
+        self.assertArgSizeInArg(NSFont.getBoundingRects_forCGGlyphs_count_, 1, 2)
 
+        self.assertArgIsOut(NSFont.getAdvancements_forCGGlyphs_count_, 0)
+        self.assertArgIsIn(NSFont.getAdvancements_forCGGlyphs_count_, 1)
+        self.assertArgSizeInArg(NSFont.getAdvancements_forCGGlyphs_count_, 0, 2)
+        self.assertArgSizeInArg(NSFont.getAdvancements_forCGGlyphs_count_, 1, 2)
 
     @min_os_level('10.7')
     def testMethods10_7(self):
@@ -113,12 +113,17 @@ class TestNSFont(TestCase):
 
     def testMethods(self):
         self.assertResultIsBOOL(NSFont.isFixedPitch)
+        self.assertArgIsOut(NSFont.getBoundingRects_forGlyphs_count_, 0)
         self.assertArgHasType(NSFont.getBoundingRects_forGlyphs_count_, 1, b'n^I')
         self.assertArgSizeInArg(NSFont.getBoundingRects_forGlyphs_count_, 0, 2)
         self.assertArgSizeInArg(NSFont.getBoundingRects_forGlyphs_count_, 1, 2)
+        self.assertArgIsOut(NSFont.getAdvancements_forGlyphs_count_, 0)
         self.assertArgHasType(NSFont.getAdvancements_forGlyphs_count_, 1, b'n^I')
         self.assertArgSizeInArg(NSFont.getAdvancements_forGlyphs_count_, 0, 2)
         self.assertArgSizeInArg(NSFont.getAdvancements_forGlyphs_count_, 1, 2)
+        if hasattr(NSFont, 'getAdvancements_forPackedGlyphs_count_'):
+            self.assertArgIsOut(NSFont.getAdvancements_forPackedGlyphs_count_, 0)
+            self.assertArgIsIn(NSFont.getAdvancements_forPackedGlyphs_count_, 1)
         self.assertArgSizeInArg(NSFont.getAdvancements_forPackedGlyphs_length_, 0, 2)
         self.assertArgSizeInArg(NSFont.getAdvancements_forPackedGlyphs_length_, 1, 2)
 
@@ -138,8 +143,10 @@ class TestNSFont(TestCase):
 
         self.assertArgHasType(NSFont.positionOfGlyph_struckOverGlyph_metricsExist_, 2, b'o^' + objc._C_NSBOOL)
         self.assertArgHasType(NSFont.positionOfGlyph_struckOverRect_metricsExist_, 2, b'o^' + objc._C_NSBOOL)
-        self.assertArgHasType(NSFont.positionOfGlyph_withRelation_toBaseGlyph_totalAdvancement_metricsExist_, 3, b'o^' + NSSize.__typestr__)
-        self.assertArgHasType(NSFont.positionOfGlyph_withRelation_toBaseGlyph_totalAdvancement_metricsExist_, 4, b'o^' + objc._C_NSBOOL)
+
+        if os_level_key(os_release()) < os_level_key('10.10'):
+            self.assertArgHasType(NSFont.positionOfGlyph_withRelation_toBaseGlyph_totalAdvancement_metricsExist_, 3, b'o^' + NSSize.__typestr__)
+            self.assertArgHasType(NSFont.positionOfGlyph_withRelation_toBaseGlyph_totalAdvancement_metricsExist_, 4, b'o^' + objc._C_NSBOOL)
 
 
     def testFunctions(self):
