@@ -2,16 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 class TestNSGraphics (TestCase):
     def testConstants(self):
@@ -29,15 +19,64 @@ class TestNSGraphics (TestCase):
         self.assertEqual(NSCompositePlusDarker, 11)
         self.assertEqual(NSCompositeHighlight, 12)
         self.assertEqual(NSCompositePlusLighter, 13)
+        self.assertEqual(NSCompositeMultiply, 14)
+        self.assertEqual(NSCompositeScreen, 15)
+        self.assertEqual(NSCompositeOverlay, 16)
+        self.assertEqual(NSCompositeDarken, 17)
+        self.assertEqual(NSCompositeLighten, 18)
+        self.assertEqual(NSCompositeColorDodge, 19)
+        self.assertEqual(NSCompositeColorBurn, 20)
+        self.assertEqual(NSCompositeSoftLight, 21)
+        self.assertEqual(NSCompositeHardLight, 22)
+        self.assertEqual(NSCompositeDifference, 23)
+        self.assertEqual(NSCompositeExclusion, 24)
+        self.assertEqual(NSCompositeHue, 25)
+        self.assertEqual(NSCompositeSaturation, 26)
+        self.assertEqual(NSCompositeColor, 27)
+        self.assertEqual(NSCompositeLuminosity, 28)
+
+        self.assertEqual(NSCompositingOperationClear, 0)
+        self.assertEqual(NSCompositingOperationCopy, 1)
+        self.assertEqual(NSCompositingOperationSourceOver, 2)
+        self.assertEqual(NSCompositingOperationSourceIn, 3)
+        self.assertEqual(NSCompositingOperationSourceOut, 4)
+        self.assertEqual(NSCompositingOperationSourceAtop, 5)
+        self.assertEqual(NSCompositingOperationDestinationOver, 6)
+        self.assertEqual(NSCompositingOperationDestinationIn, 7)
+        self.assertEqual(NSCompositingOperationDestinationOut, 8)
+        self.assertEqual(NSCompositingOperationDestinationAtop, 9)
+        self.assertEqual(NSCompositingOperationXOR, 10)
+        self.assertEqual(NSCompositingOperationPlusDarker, 11)
+        self.assertEqual(NSCompositingOperationHighlight, 12)
+        self.assertEqual(NSCompositingOperationPlusLighter, 13)
+        self.assertEqual(NSCompositingOperationMultiply, 14)
+        self.assertEqual(NSCompositingOperationScreen, 15)
+        self.assertEqual(NSCompositingOperationOverlay, 16)
+        self.assertEqual(NSCompositingOperationDarken, 17)
+        self.assertEqual(NSCompositingOperationLighten, 18)
+        self.assertEqual(NSCompositingOperationColorDodge, 19)
+        self.assertEqual(NSCompositingOperationColorBurn, 20)
+        self.assertEqual(NSCompositingOperationSoftLight, 21)
+        self.assertEqual(NSCompositingOperationHardLight, 22)
+        self.assertEqual(NSCompositingOperationDifference, 23)
+        self.assertEqual(NSCompositingOperationExclusion, 24)
+        self.assertEqual(NSCompositingOperationHue, 25)
+        self.assertEqual(NSCompositingOperationSaturation, 26)
+        self.assertEqual(NSCompositingOperationColor, 27)
+        self.assertEqual(NSCompositingOperationLuminosity, 28)
+
         self.assertEqual(NSBackingStoreRetained, 0)
         self.assertEqual(NSBackingStoreNonretained, 1)
         self.assertEqual(NSBackingStoreBuffered, 2)
+
         self.assertEqual(NSWindowAbove,  1)
         self.assertEqual(NSWindowBelow, -1)
         self.assertEqual(NSWindowOut,  0)
+
         self.assertEqual(NSFocusRingOnly, 0)
         self.assertEqual(NSFocusRingBelow, 1)
         self.assertEqual(NSFocusRingAbove, 2)
+
         self.assertEqual(NSFocusRingTypeDefault, 0)
         self.assertEqual(NSFocusRingTypeNone, 1)
         self.assertEqual(NSFocusRingTypeExterior, 2)
@@ -66,6 +105,10 @@ class TestNSGraphics (TestCase):
         self.assertEqual(NSAnimationEffectDisappearingItemDefault, 0)
         self.assertEqual(NSAnimationEffectPoof, 10)
 
+        self.assertEqual(NSDisplayGamutSRGB, 1)
+        self.assertEqual(NSDisplayGamutP3, 2)
+
+
 
     def testFunctions(self):
         app = NSApplication.sharedApplication()
