@@ -3,16 +3,6 @@ import os
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-
-try:
-    long
-except NameError:
-    long = int
 
 
 class TestNSHFSFileTypes (TestCase):
@@ -26,6 +16,8 @@ class TestNSHFSFileTypes (TestCase):
         fname = '/Library/Documentation/Acknowledgements.rtf'
         if not os.path.exists(fname):
             fname = '/Library/Documentation/AirPort Acknowledgements.rtf'
+        if not os.path.exists(fname):
+            fname = '/Library/Documentation//iPod/Acknowledgements.rtf'
 
         if not os.path.exists(fname):
             self.fail("test file doesn't exist")
