@@ -13,20 +13,20 @@ class TestNSHost (TestCase):
         # implementation of -hostWithAddress: and -hostWithName: yet the latter
         # does not have the problem we're seeing here.
         #
-        o = NSHost.hostWithAddress_(u'127.0.0.1')
-        self.assertEqual(o.addresses(), (u'127.0.0.1',))
-        self.assertEqual(o.address(), u'127.0.0.1')
+        o = NSHost.hostWithAddress_(b'127.0.0.1'.decode('ascii'))
+        self.assertEqual(o.addresses(), (b'127.0.0.1'.decode('ascii'),))
+        self.assertEqual(o.address(), b'127.0.0.1'.decode('ascii'))
 
     def testCreation2(self):
-        o = NSHost.hostWithName_(u'localhost')
+        o = NSHost.hostWithName_(b'localhost'.decode('ascii'))
         l = list(o.addresses())
         l.sort()
-        #self.assert_(l in ([u'127.0.0.1', u'::1'], [u'127.0.0.1']))
+        #self.assertIn(l, ([b'127.0.0.1'.decode('ascii'), b'::1'.decode('ascii')], [b'127.0.0.1'.decode('ascii')]))
         self.assertEqual(o.address(), o.addresses()[0])
 
     def testIndirectCreation(self):
-        o = PyObjC_TestClass3.createAHostWithAddress_(u'127.0.0.1')
-        self.assertEqual(o.address(), u'127.0.0.1')
+        o = PyObjC_TestClass3.createAHostWithAddress_(b'127.0.0.1'.decode('ascii'))
+        self.assertEqual(o.address(), b'127.0.0.1'.decode('ascii'))
 
     def testMethods(self):
         self.assertArgIsBOOL(NSHost.setHostCacheEnabled_, 0)
