@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSHTTPCookieStorage (TestCase):
     def testConstants(self):
         self.assertEqual(NSHTTPCookieAcceptPolicyAlways, 0)
@@ -16,5 +11,9 @@ class TestNSHTTPCookieStorage (TestCase):
         self.assertIsInstance(NSHTTPCookieManagerAcceptPolicyChangedNotification, unicode)
         self.assertIsInstance(NSHTTPCookieManagerCookiesChangedNotification, unicode)
 
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertArgIsBlock(NSHTTPCookieStorage.getCookiesForTask_completionHandler_, 1, b'v@')
+
 if __name__ == "__main__":
     main()
