@@ -13,6 +13,11 @@ class TestNSIndexPath (TestCase):
         self.assertArgIsOut(NSIndexPath.getIndexes_, 0)
         self.assertArgIsVariableSize(NSIndexPath.getIndexes_, 0)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        self.assertArgIsOut(NSIndexPath.getIndexes_range_, 0)
+        self.assertArgSizeInArg(NSIndexPath.getIndexes_range_, 0, 1)
+
     def testConvenience(self):
         path = NSIndexPath.indexPathWithIndexes_length_([0, 1, 4], 3)
 
@@ -26,6 +31,9 @@ class TestNSIndexPath (TestCase):
         self.assertEqual(len(p2), len(path) + 1)
         self.assertEqual(p2[3], 9)
 
+        with self.assertRaises(ValueError):
+            p2[1:3]
+
 
 if __name__ == "__main__":
     main()
