@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSNetServicesHelper (NSObject):
     def netServiceBrowser_didFindDomain_moreComing_(self, a, b, c): pass
     def netServiceBrowser_didFindService_moreComing_(self, a, b, c): pass
@@ -16,7 +11,6 @@ class TestNSNetServicesHelper (NSObject):
 
 class TestNSNetservices (TestCase):
     def testConstants(self):
-
         self.assertIsInstance(NSNetServicesErrorCode, unicode)
         self.assertIsInstance(NSNetServicesErrorDomain, unicode)
         self.assertEqual(NSNetServicesUnknownError, -72000)
@@ -29,6 +23,10 @@ class TestNSNetservices (TestCase):
         self.assertEqual(NSNetServicesTimeoutError, -72007)
         self.assertEqual(NSNetServiceNoAutoRename, 1)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertEqual(NSNetServiceListenForConnections, 1<<1)
+
     def testOutput(self):
         o = NSNetService.alloc().init()
 
@@ -48,5 +46,18 @@ class TestNSNetservices (TestCase):
         self.assertArgIsBOOL(TestNSNetServicesHelper.netServiceBrowser_didRemoveDomain_moreComing_, 2)
         self.assertArgIsBOOL(TestNSNetServicesHelper.netServiceBrowser_didRemoveService_moreComing_, 2)
 
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(NSNetService.includesPeerToPeer)
+        self.assertArgIsBOOL(NSNetService.setIncludesPeerToPeer_, 0)
+
+        self.assertResultIsBOOL(NSNetServiceBrowser.includesPeerToPeer)
+        self.assertArgIsBOOL(NSNetServiceBrowser.setIncludesPeerToPeer_, 0)
+
+    @min_sdk_level('10.10')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSNetServiceDelegate')
+        objc.protocolNamed('NSNetServiceBrowserDelegate')
+
 if __name__ == "__main__":
     main()
