@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSNib (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSNibOwner, unicode)
@@ -16,6 +11,8 @@ class TestNSNib (TestCase):
         self.assertResultIsBOOL(NSNib.instantiateNibWithOwner_topLevelObjects_)
         self.assertArgIsOut(NSNib.instantiateNibWithOwner_topLevelObjects_, 1)
 
+        self.assertResultIsBOOL(NSNib.instantiateNibWithExternalNameTable_)
+
     @min_os_level('10.8')
     def testMethods10_8(self):
         self.assertResultIsBOOL(NSNib.instantiateWithOwner_topLevelObjects_)
