@@ -4,9 +4,8 @@ from Foundation import NSNull
 class TestNSNull (TestCase):
     def testBool(self):
         v = NSNull.null()
-        print bool(v)
-        self.assert_(not v)
-        self.assert_(v is not None)
+        self.assertFalse(v)
+        self.assertIsNot(v, None)
 
 if __name__ == "__main__":
     main()
