@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    long
-except NameError:
-    long = int
-
 
 class TestNSOpenGL (TestCase):
     def testConstants(self):
@@ -14,8 +9,10 @@ class TestNSOpenGL (TestCase):
         self.assertEqual(NSOpenGLGOClearFormatCache, 502)
         self.assertEqual(NSOpenGLGORetainRenderers, 503)
         self.assertEqual(NSOpenGLGOResetLibrary, 504)
+        self.assertEqual(NSOpenGLGOUseBuildCache, 506)
 
         self.assertEqual(NSOpenGLPFAAllRenderers,   1)
+        self.assertEqual(NSOpenGLPFATripleBuffer,   3)
         self.assertEqual(NSOpenGLPFADoubleBuffer,   5)
         self.assertEqual(NSOpenGLPFAStereo,   6)
         self.assertEqual(NSOpenGLPFAAuxBuffers,   7)
@@ -58,6 +55,30 @@ class TestNSOpenGL (TestCase):
         self.assertEqual(NSOpenGLCPSurfaceOrder, 235)
         self.assertEqual(NSOpenGLCPSurfaceOpacity, 236)
         self.assertEqual(NSOpenGLCPStateValidation, 301)
+        self.assertEqual(NSOpenGLCPSurfaceBackingSize, 304)
+        self.assertEqual(NSOpenGLCPReclaimResources, 308)
+        self.assertEqual(NSOpenGLCPCurrentRendererID, 309)
+        self.assertEqual(NSOpenGLCPGPUVertexProcessing, 310)
+        self.assertEqual(NSOpenGLCPGPUFragmentProcessing, 311)
+        self.assertEqual(NSOpenGLCPHasDrawable, 314)
+        self.assertEqual(NSOpenGLCPMPSwapsInFlight, 315)
+        self.assertEqual(NSOpenGLCPSurfaceSurfaceVolatile, 306)
+
+        self.assertEqual(NSOpenGLContextParameterSwapInterval, 222)
+        self.assertEqual(NSOpenGLContextParameterSurfaceOrder, 235)
+        self.assertEqual(NSOpenGLContextParameterSurfaceOpacity, 236)
+        self.assertEqual(NSOpenGLContextParameterSurfaceBackingSize, 304)
+        self.assertEqual(NSOpenGLContextParameterReclaimResources, 308)
+        self.assertEqual(NSOpenGLContextParameterCurrentRendererID, 309)
+        self.assertEqual(NSOpenGLContextParameterGPUVertexProcessing, 310)
+        self.assertEqual(NSOpenGLContextParameterGPUFragmentProcessing, 311)
+        self.assertEqual(NSOpenGLContextParameterHasDrawable, 314)
+        self.assertEqual(NSOpenGLContextParameterMPSwapsInFlight, 315)
+        self.assertEqual(NSOpenGLContextParameterSwapRectangle, 200)
+        self.assertEqual(NSOpenGLContextParameterSwapRectangleEnable, 201)
+        self.assertEqual(NSOpenGLContextParameterRasterizationEnable, 221)
+        self.assertEqual(NSOpenGLContextParameterStateValidation, 301)
+        self.assertEqual(NSOpenGLContextParameterSurfaceSurfaceVolatile, 306)
 
     @min_os_level("10.5")
     def testConstants10_5(self):
@@ -69,6 +90,10 @@ class TestNSOpenGL (TestCase):
         self.assertEqual(NSOpenGLProfileVersionLegacy, 0x1000)
         self.assertEqual(NSOpenGLProfileVersion3_2Core, 0x3200)
 
+    @min_os_level("10.10")
+    def testConstants10_10(self):
+        self.assertEqual(NSOpenGLProfileVersion4_1Core, 0x4100)
+
 
     def testFunctions(self):
         major, minor = NSOpenGLGetVersion(None, None)
@@ -100,6 +125,15 @@ class TestNSOpenGL (TestCase):
         self.assertResultHasType(NSOpenGLContext.CGLContextObj,
                 b'^{_CGLContextObj}')
 
+        self.assertArgIsIn(NSOpenGLContext.setValues_forParameter_, 0)
+        self.assertArgIsVariableSize(NSOpenGLContext.setValues_forParameter_, 0)
+
+        self.assertArgIsIn(NSOpenGLContext.setValues_forParameter_, 0)
+        self.assertArgIsVariableSize(NSOpenGLContext.setValues_forParameter_, 0)
+
+        self.assertArgIsIn(NSOpenGLContext.setOffScreen_width_height_rowbytes_, 0)
+        self.assertArgIsVariableSize(NSOpenGLContext.setOffScreen_width_height_rowbytes_, 0)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertArgHasType(NSOpenGLPixelFormat.initWithCGLPixelFormatObj_, 0, b'^{_CGLPixelFormatObject}')
