@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSParagraphStyle (TestCase):
     def testConstants(self):
         self.assertEqual(NSLeftTabStopType, 0)
@@ -23,5 +18,10 @@ class TestNSParagraphStyle (TestCase):
 
         self.assertIsInstance(NSTabColumnTerminatorsAttributeName, unicode)
 
+    @min_os_level('10.11')
+    def testMethods10_11(self):
+        self.assertResultIsBOOL(NSParagraphStyle.allowsDefaultTighteningForTruncation)
+        self.assertArgIsBOOL(NSMutableParagraphStyle.setAllowsDefaultTighteningForTruncation_, 0)
+
 if __name__ == "__main__":
     main()
