@@ -2,10 +2,9 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
+class TestNSPasteboardHelper (NSObject):
+    def writingOptionsForType_pasteboard_(self, t, p): return 1
+    def readingOptionsForType_pasteboard_(self, t, p): return 1
 
 class TestNSPasteboard (TestCase):
     def testConstants(self):
@@ -88,6 +87,20 @@ class TestNSPasteboard (TestCase):
         self.assertEqual(NSPasteboardReadingAsPropertyList, 1<<1)
         self.assertEqual(NSPasteboardReadingAsKeyedArchive, 1<<2)
 
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertEqual(NSPasteboardContentsCurrentHostOnly, 1<<0)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(NSPasteboardNameGeneral, unicode)
+        self.assertIsInstance(NSPasteboardNameFont, unicode)
+        self.assertIsInstance(NSPasteboardNameRuler, unicode)
+        self.assertIsInstance(NSPasteboardNameFind, unicode)
+        self.assertIsInstance(NSPasteboardNameDrag, unicode)
+        self.assertIsInstance(NSPasteboardTypeURL, unicode)
+        self.assertIsInstance(NSPasteboardTypeFileURL, unicode)
+
 
     @min_os_level('10.6')
     def testMethods10_6(self):
@@ -98,5 +111,20 @@ class TestNSPasteboard (TestCase):
         self.assertResultIsBOOL(NSPasteboard.setPropertyList_forType_)
         self.assertResultIsBOOL(NSPasteboard.setString_forType_)
 
+    @min_sdk_level('10.6')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSPasteboardWriting')
+        objc.protocolNamed('NSPasteboardReading')
+
+    @min_sdk_level('10.14')
+    def testProtocolObjects10_14(self):
+        objc.protocolNamed('NSPasteboardTypeOwner')
+
+    def testProtocols(self):
+        self.assertResultHasType(TestNSPasteboardHelper.writingOptionsForType_pasteboard_, objc._C_NSUInteger)
+
+        self.assertResultHasType(TestNSPasteboardHelper.readingOptionsForType_pasteboard_, objc._C_NSUInteger)
+
+
 if __name__ == "__main__":
     main()
