@@ -3,14 +3,9 @@ from PyObjCTools.TestSupport import *
 from objc import *
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSPathUtilities(TestCase):
     def testSearchPaths(self):
-        self.assert_(
+        self.assertTrue(
                 NSSearchPathForDirectoriesInDomains( NSAllLibrariesDirectory, NSAllDomainsMask, NO ),
                       "NSSearchPathForDirectoriesInDomains() failed to return anything." )
 
@@ -18,13 +13,13 @@ class TestNSPathUtilities(TestCase):
 
     def testTrue(self):
         for boolVal in (1, 1==1, YES, -1):
-            self.assert_(
-                NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,NSUserDomainMask, boolVal)[0][0] == '/', boolVal)
+            self.assertEqual(
+                NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,NSUserDomainMask, boolVal)[0][0], '/', boolVal)
 
     def testFalse(self):
         for boolVal in (0, 1!=1, NO):
-            self.assert_(
-                NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,NSUserDomainMask, boolVal)[0][0] != '/', boolVal)
+            self.assertNotEqual(
+                NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,NSUserDomainMask, boolVal)[0][0], '/', boolVal)
 
     def testFunctions(self):
         s = NSUserName()
