@@ -2,16 +2,12 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSPopUpButton (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSPopUpButtonWillPopUpNotification, unicode)
 
     def testMethods(self):
+        self.assertArgIsBOOL(NSPopUpButton.initWithFrame_pullsDown_, 1)
         self.assertResultIsBOOL(NSPopUpButton.pullsDown)
         self.assertArgIsBOOL(NSPopUpButton.setPullsDown_, 0)
         self.assertResultIsBOOL(NSPopUpButton.autoenablesItems)
