@@ -2,10 +2,8 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
+class PortDelegate (NSObject):
+    def handleMachMessage_(self, m): pass
 
 class NSPortHelper (NSPort):
     def sendBeforeDate_components_from_reserved_(self, a, b, c, d): pass
@@ -27,5 +25,12 @@ class TestNSPort (TestCase):
         self.assertArgHasType(NSPortHelper.sendBeforeDate_components_from_reserved_, 3, objc._C_NSUInteger)
         self.assertArgHasType(NSPortHelper.sendBeforeDate_msgid_components_from_reserved_, 4, objc._C_NSUInteger)
 
+        self.assertArgHasType(PortDelegate.handleMachMessage_, 0, b'^v')
+
+    @min_sdk_level('10.6')
+    def testProtocols(self):
+        objc.protocolNamed('NSPortDelegate')
+        objc.protocolNamed('NSMachPortDelegate')
+
 if __name__ == "__main__":
     main()
