@@ -2,12 +2,9 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSPrintPanel (TestCase):
+    def testProtocols(self):
+        objc.protocolNamed('NSPrintPanelAccessorizing')
 
     def testConstants(self):
         self.assertEqual(NSPrintPanelShowsCopies, 0x01)
