@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSScreen (TestCase):
     def testMethods(self):
         m = NSScreen.supportedWindowDepths.__metadata__()
@@ -25,5 +20,13 @@ class TestNSScreen (TestCase):
         self.assertResultHasType(NSScreen.backingAlignedRect_options_, NSRect.__typestr__)
         self.assertArgHasType(NSScreen.backingAlignedRect_options_, 0, NSRect.__typestr__)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        self.assertResultIsBOOL(NSScreen.screensHaveSeparateSpaces)
+
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSScreen.canRepresentDisplayGamut_)
+
 if __name__ == "__main__":
     main()
