@@ -3,9 +3,9 @@ from PyObjCTools.TestSupport import *
 
 class TestNSScriptStandardSuiteCommands (TestCase):
     def testCommands(self):
-        self.failUnlessEqual(NSSaveOptionsYes, 0)
-        self.failUnlessEqual(NSSaveOptionsNo, 1)
-        self.failUnlessEqual(NSSaveOptionsAsk, 2)
+        self.assertEqual(NSSaveOptionsYes, 0)
+        self.assertEqual(NSSaveOptionsNo, 1)
+        self.assertEqual(NSSaveOptionsAsk, 2)
 
 if __name__ == "__main__":
     main()
