@@ -8,9 +8,20 @@ class TestNSSliderCell (TestCase):
         self.assertEqual(NSTickMarkAbove, 1)
         self.assertEqual(NSTickMarkLeft, NSTickMarkAbove)
         self.assertEqual(NSTickMarkRight, NSTickMarkBelow)
+
         self.assertEqual(NSLinearSlider, 0)
         self.assertEqual(NSCircularSlider, 1)
 
+        self.assertEqual(NSTickMarkPositionBelow, 0)
+        self.assertEqual(NSTickMarkPositionAbove, 1)
+        self.assertEqual(NSTickMarkPositionLeading, NSTickMarkPositionAbove)
+        self.assertEqual(NSTickMarkPositionTrailing, NSTickMarkPositionBelow)
+
+        self.assertEqual(NSSliderTypeLinear, 0)
+        self.assertEqual(NSSliderTypeCircular, 1)
+
+
+
     def testMethods(self):
         self.assertResultIsBOOL(NSSliderCell.prefersTrackingUntilMouseUp)
         self.assertArgIsBOOL(NSSliderCell.knobRectFlipped_, 0)
@@ -18,5 +29,9 @@ class TestNSSliderCell (TestCase):
         self.assertResultIsBOOL(NSSliderCell.allowsTickMarkValuesOnly)
         self.assertArgIsBOOL(NSSliderCell.setAllowsTickMarkValuesOnly_, 0)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        self.assertArgIsBOOL(NSSliderCell.barRectFlipped_, 0)
+
 if __name__ == "__main__":
     main()
