@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSSoundHelper (NSObject):
     def sound_didFinishPlaying_(self, s, p): pass
 
@@ -28,6 +23,10 @@ class TestNSSound (TestCase):
         self.assertResultIsBOOL(NSSound.loops)
         self.assertArgIsBOOL(NSSound.setLoops_, 0)
 
+    @min_os_level('10.10')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSSoundDelegate')
+
     def testProtocols(self):
         self.assertArgIsBOOL(TestNSSoundHelper.sound_didFinishPlaying_, 1)
 
