@@ -8,5 +8,9 @@ class TestNSSpeechRecognizer (TestCase):
         self.assertArgIsBOOL(NSSpeechRecognizer.setListensInForegroundOnly_, 0)
         self.assertArgIsBOOL(NSSpeechRecognizer.setBlocksOtherRecognizers_, 0)
 
+    @min_sdk_level('10.10')
+    def testProtocols(self):
+        objc.protocolNamed('NSSpeechRecognizerDelegate')
+
 if __name__ == "__main__":
     main()
