@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSSpellChecker (TestCase):
     def testMethods(self):
         self.assertResultIsBOOL(NSSpellChecker.sharedSpellCheckerExists)
@@ -50,6 +45,20 @@ class TestNSSpellChecker (TestCase):
         self.assertResultIsBOOL(NSSpellChecker.isAutomaticTextReplacementEnabled)
         self.assertResultIsBOOL(NSSpellChecker.isAutomaticSpellingCorrectionEnabled)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        self.assertResultIsBOOL(NSSpellChecker.isAutomaticQuoteSubstitutionEnabled)
+        self.assertResultIsBOOL(NSSpellChecker.isAutomaticDashSubstitutionEnabled)
+
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSSpellChecker.preventsAutocorrectionBeforeString_language_)
+        self.assertResultIsBOOL(NSSpellChecker.isAutomaticCapitalizationEnabled)
+        self.assertResultIsBOOL(NSSpellChecker.isAutomaticPeriodSubstitutionEnabled)
+        self.assertResultIsBOOL(NSSpellChecker.isAutomaticTextCompletionEnabled)
+
+        self.assertArgIsBlock(NSSpellChecker.requestCandidatesForSelectedRange_inString_types_options_inSpellDocumentWithTag_completionHandler_, 5, b'v' + objc._C_NSInteger + b'@')
+
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -68,7 +77,28 @@ class TestNSSpellChecker (TestCase):
         self.assertIsInstance(NSSpellCheckerDidChangeAutomaticSpellingCorrectionNotification, unicode)
         self.assertIsInstance(NSSpellCheckerDidChangeAutomaticTextReplacementNotification, unicode)
 
+        self.assertEqual(NSCorrectionResponseNone, 0)
+        self.assertEqual(NSCorrectionResponseAccepted, 1)
+        self.assertEqual(NSCorrectionResponseRejected, 2)
+        self.assertEqual(NSCorrectionResponseIgnored, 3)
+        self.assertEqual(NSCorrectionResponseEdited, 4)
+        self.assertEqual(NSCorrectionResponseReverted, 5)
 
+        self.assertEqual(NSCorrectionIndicatorTypeDefault, 0)
+        self.assertEqual(NSCorrectionIndicatorTypeReversion, 1)
+        self.assertEqual(NSCorrectionIndicatorTypeGuesses, 2)
+
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertIsInstance(NSSpellCheckerDidChangeAutomaticQuoteSubstitutionNotification, unicode)
+        self.assertIsInstance(NSSpellCheckerDidChangeAutomaticDashSubstitutionNotification, unicode)
+
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(NSTextCheckingSelectedRangeKey, unicode)
+        self.assertIsInstance(NSSpellCheckerDidChangeAutomaticCapitalizationNotification, unicode)
+        self.assertIsInstance(NSSpellCheckerDidChangeAutomaticPeriodSubstitutionNotification, unicode)
+        self.assertIsInstance(NSSpellCheckerDidChangeAutomaticTextCompletionNotification, unicode)
 
 
 if __name__ == "__main__":
