@@ -2,17 +2,12 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSTableViewHelper (NSObject):
+    def tableView_rowActionsForRow_edge_(self, a, b, c): pass
     def tableView_viewForTableColumn_row_(self, a, b, c): pass
     def tableView_rowViewForRow_(self, a, b): pass
     def tableView_didAddRowView_forRow_(self, a, b, c): pass
     def tableView_didRemoveRowView_forRow_(self, a, b, c): pass
-    def tableView_pastboardWriterForRow_(self, a, b): pass
     def tableView_draggingSession_willBeginAtPoint_forRowIndexes_(self, a, b, c, d): pass
     def tableView_draggingSession_endedAtPoint_operation_(self, a, b, c, d): pass
 
@@ -27,6 +22,7 @@ class TestNSTableViewHelper (NSObject):
     def tableView_willDisplayCell_forTableColumn_row_(self, tv, c, tc, r): return 1
     def tableView_shouldEditTableColumn_row_(self, tv, tc, r): return 1
     def selectionShouldChangeInTableView_(self, tv): return 1
+    def tableView_shouldSelectRow_(self, tv, r): return 1
     def tableView_shouldSelectTableColumn_(self, tv, tc): return 1
     def tableView_toolTipForCell_rect_tableColumn_row_mouseLocation_(self, tv, c, re, tc, r, l): return 1
     def tableView_heightOfRow_(self, tv, r): return 1
@@ -40,6 +36,7 @@ class TestNSTableViewHelper (NSObject):
 
     def tableView_sizeToFitWidthOfColumn_(self, tv, c): return 1
     def tableView_shouldReorderColumn_toColumn_(self, tv, c1, c2): return 1
+    def tableView_pasteboardWriterForRow_(self, tv, r): return 1
 
 
 
@@ -79,6 +76,7 @@ class TestNSTableView (TestCase):
     @min_os_level('10.7')
     def testConstants10_7(self):
         self.assertEqual(NSTableViewDashedHorizontalGridLineMask, 1<<3)
+
         self.assertEqual(NSTableViewRowSizeStyleDefault, -1)
         self.assertEqual(NSTableViewRowSizeStyleCustom, 0)
         self.assertEqual(NSTableViewRowSizeStyleSmall, 1)
@@ -97,6 +95,15 @@ class TestNSTableView (TestCase):
 
         self.assertEqual(NSTableViewDashedHorizontalGridLineMask, 1<<3)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertEqual(NSTableViewDraggingDestinationFeedbackStyleGap, 2)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertEqual(NSTableRowActionEdgeLeading, 0)
+        self.assertEqual(NSTableRowActionEdgeTrailing, 1)
+
     def testMethods(self):
         self.assertArgIsBOOL(NSTableView.setAllowsColumnReordering_, 0)
         self.assertResultIsBOOL(NSTableView.allowsColumnReordering)
@@ -128,8 +135,6 @@ class TestNSTableView (TestCase):
 
         self.assertArgHasType(NSTableView.drawBackgroundInClipRect_, 0, NSRect.__typestr__)
 
-
-
         self.assertArgIsBOOL(NSTableView.setDrawsGrid_, 0)
         self.assertResultIsBOOL(NSTableView.drawsGrid)
         self.assertArgIsBOOL(NSTableView.selectColumn_byExtendingSelection_, 1)
@@ -159,6 +164,26 @@ class TestNSTableView (TestCase):
         self.assertResultIsBOOL(NSTableView.floatsGroupRows)
         self.assertArgIsBOOL(NSTableView.setFloatsGroupRows_, 0)
 
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(NSTableView.usesStaticContents)
+        self.assertArgIsBOOL(NSTableView.setUsesStaticContents_, 0)
+
+    @min_os_level('10.11')
+    def testMethods10_11(self):
+        self.assertResultIsBOOL(NSTableView.rowActionsVisible)
+        self.assertArgIsBOOL(NSTableView.setRowActionsVisible_, 0)
+
+    @min_os_level('10.13')
+    def testMethods10_13(self):
+        self.assertResultIsBOOL(NSTableView.usesAutomaticRowHeights)
+        self.assertArgIsBOOL(NSTableView.setUsesAutomaticRowHeights_, 0)
+
+    @min_sdk_level('10.6')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSTableViewDelegate')
+        objc.protocolNamed('NSTableViewDataSource')
+
     def testProtocols(self):
         self.assertResultHasType(TestNSTableViewHelper.numberOfRowsInTableView_, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_objectValueForTableColumn_row_, 2, objc._C_NSInteger)
@@ -177,6 +202,7 @@ class TestNSTableView (TestCase):
         self.assertResultIsBOOL(TestNSTableViewHelper.tableView_shouldEditTableColumn_row_)
         self.assertArgHasType(TestNSTableViewHelper.tableView_shouldEditTableColumn_row_, 2, objc._C_NSInteger)
         self.assertResultIsBOOL(TestNSTableViewHelper.selectionShouldChangeInTableView_)
+        self.assertResultIsBOOL(TestNSTableViewHelper.tableView_shouldSelectRow_)
         self.assertResultIsBOOL(TestNSTableViewHelper.tableView_shouldSelectTableColumn_)
         self.assertArgHasType(TestNSTableViewHelper.tableView_toolTipForCell_rect_tableColumn_row_mouseLocation_, 2, b'N^' + NSRect.__typestr__)
         self.assertArgHasType(TestNSTableViewHelper.tableView_toolTipForCell_rect_tableColumn_row_mouseLocation_, 4, objc._C_NSInteger)
@@ -197,7 +223,7 @@ class TestNSTableView (TestCase):
         self.assertArgHasType(TestNSTableViewHelper.tableView_isGroupRow_, 1, objc._C_NSInteger)
 
     @min_os_level('10.6')
-    def testProtococols10_6(self):
+    def testProtocols10_6(self):
         self.assertResultHasType(TestNSTableViewHelper.tableView_sizeToFitWidthOfColumn_, objc._C_CGFloat)
         self.assertArgHasType(TestNSTableViewHelper.tableView_sizeToFitWidthOfColumn_, 1, objc._C_NSInteger)
 
@@ -206,15 +232,20 @@ class TestNSTableView (TestCase):
         self.assertArgHasType(TestNSTableViewHelper.tableView_shouldReorderColumn_toColumn_, 2, objc._C_NSInteger)
 
     @min_os_level('10.7')
-    def testProtococols10_7(self):
+    def testProtocols10_7(self):
+        self.assertArgHasType(TestNSTableViewHelper.tableView_pasteboardWriterForRow_, 1, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_viewForTableColumn_row_, 2, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_rowViewForRow_, 1, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_didAddRowView_forRow_, 2, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_didRemoveRowView_forRow_, 2, objc._C_NSInteger)
-        self.assertArgHasType(TestNSTableViewHelper.tableView_pastboardWriterForRow_, 1, objc._C_NSInteger)
         self.assertArgHasType(TestNSTableViewHelper.tableView_draggingSession_willBeginAtPoint_forRowIndexes_, 2, NSPoint.__typestr__)
         self.assertArgHasType(TestNSTableViewHelper.tableView_draggingSession_endedAtPoint_operation_, 2, NSPoint.__typestr__)
 
+    @min_os_level('10.11')
+    def testProtococols10_11(self):
+        self.assertArgHasType(TestNSTableViewHelper.tableView_rowActionsForRow_edge_, 1, objc._C_NSInteger)
+        self.assertArgHasType(TestNSTableViewHelper.tableView_rowActionsForRow_edge_, 2, objc._C_NSInteger)
+
 
 if __name__ == "__main__":
     main()
