@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestNSTextViewHelper (NSObject):
     def textView_URLForContentsOfTextAttachment_atIndex_(self, a, b, c): pass
     def textView_clickedOnLink_atIndex_(self, tv, a, b): return 1
@@ -30,13 +25,19 @@ class TestNSTextViewHelper (NSObject):
     def textView_willCheckTextInRange_options_types_(self, tv, a, b, c): return 1
     def textView_didCheckTextInRange_types_options_results_orthography_wordCount_(self, tv, r, t, o, rs, ort, wc): return 1
 
+    def textView_candidatesForSelectedRange_(self, tv, r): return 1
+    def textView_candidates_forSelectedRange_(self, tv, c, r): return 1
+    def textView_shouldSelectCandidateAtIndex_(self, tv, i): return 1
+
 class TestNSTextView (TestCase):
     def testConstants(self):
         self.assertEqual(NSSelectByCharacter, 0)
         self.assertEqual(NSSelectByWord, 1)
         self.assertEqual(NSSelectByParagraph, 2)
+
         self.assertEqual(NSSelectionAffinityUpstream, 0)
         self.assertEqual(NSSelectionAffinityDownstream, 1)
+
         self.assertEqual(NSFindPanelActionShowFindPanel, 1)
         self.assertEqual(NSFindPanelActionNext, 2)
         self.assertEqual(NSFindPanelActionPrevious, 3)
@@ -64,8 +65,20 @@ class TestNSTextView (TestCase):
         self.assertIsInstance(NSTextViewDidChangeSelectionNotification, unicode)
         self.assertIsInstance(NSTextViewDidChangeTypingAttributesNotification, unicode)
 
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(NSTouchBarItemIdentifierCharacterPicker, unicode)
+        self.assertIsInstance(NSTouchBarItemIdentifierTextColorPicker, unicode)
+        self.assertIsInstance(NSTouchBarItemIdentifierTextStyle, unicode)
+        self.assertIsInstance(NSTouchBarItemIdentifierTextAlignment, unicode)
+        self.assertIsInstance(NSTouchBarItemIdentifierTextList, unicode)
+        self.assertIsInstance(NSTouchBarItemIdentifierTextFormat, unicode)
+
+
 
     def testMethods(self):
+        self.assertResultIsBOOL(NSTextView.shouldDrawInsertionPoint)
+        #self.assertArgIsBOOL(NSTextView.setShouldDrawInsertionPoint_, 0)
         self.assertResultIsBOOL(NSTextView.rulerView_shouldMoveMarker_)
         self.assertResultIsBOOL(NSTextView.rulerView_shouldAddMarker_)
         self.assertResultIsBOOL(NSTextView.rulerView_shouldRemoveMarker_)
@@ -116,6 +129,7 @@ class TestNSTextView (TestCase):
         self.assertResultIsBOOL(NSTextView.usesFontPanel)
         self.assertArgIsBOOL(NSTextView.setUsesFontPanel_, 0)
         self.assertResultIsBOOL(NSTextView.isRulerVisible)
+        self.assertArgIsBOOL(NSTextView.setRulerVisible_, 0)
         self.assertResultIsBOOL(NSTextView.smartInsertDeleteEnabled)
         self.assertArgIsBOOL(NSTextView.setSmartInsertDeleteEnabled_, 0)
 
@@ -123,6 +137,11 @@ class TestNSTextView (TestCase):
         self.assertArgIsOut(NSTextView.smartInsertForString_replacingRange_beforeString_afterString_, 2)
         self.assertArgIsOut(NSTextView.smartInsertForString_replacingRange_beforeString_afterString_, 3)
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(NSTextView.usesRolloverButtonForSelection)
+        self.assertArgIsBOOL(NSTextView.setUsesRolloverButtonForSelection_, 0)
+
     @min_os_level('10.7')
     def testMethods10_7(self):
         self.assertResultIsBOOL(NSTextView.usesInspectorBar)
@@ -142,6 +161,10 @@ class TestNSTextView (TestCase):
         self.assertArgIsBOOL(NSTextView.setAutomaticLinkDetectionEnabled_, 0)
 
 
+    @min_sdk_level('10.6')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSTextViewDelegate')
+
     def testProtocols(self):
         self.assertResultIsBOOL(TestNSTextViewHelper.textView_clickedOnLink_atIndex_)
         self.assertArgHasType(TestNSTextViewHelper.textView_clickedOnLink_atIndex_, 2, objc._C_NSUInteger)
@@ -191,6 +214,13 @@ class TestNSTextView (TestCase):
         self.assertArgHasType(NSTextView.checkTextInRange_types_options_, 0, NSRange.__typestr__)
         self.assertArgHasType(NSTextView.handleTextCheckingResults_forRange_types_options_orthography_wordCount_, 1, NSRange.__typestr__)
 
+    @min_os_level('10.12')
+    def testMethods10_12(self):
+        self.assertResultIsBOOL(NSTextView.stronglyReferencesTextStorage)
+
+        self.assertResultIsBOOL(NSTextView.allowsCharacterPickerTouchBarItem)
+        self.assertArgIsBOOL(NSTextView.setAllowsCharacterPickerTouchBarItem_, 0)
+
     @min_os_level('10.6')
     def testProtocols10_6(self):
         self.assertArgHasType(TestNSTextViewHelper.textView_willCheckTextInRange_options_types_, 1, NSRange.__typestr__)
@@ -204,6 +234,16 @@ class TestNSTextView (TestCase):
     def testProtocols10_7(self):
         self.assertArgHasType(TestNSTextViewHelper.textView_URLForContentsOfTextAttachment_atIndex_, 2, objc._C_NSUInteger)
 
+    @min_os_level('10.12')
+    def testProtocols10_12(self):
+        self.assertArgHasType(TestNSTextViewHelper.textView_candidatesForSelectedRange_, 1, NSRange.__typestr__)
+        self.assertArgHasType(TestNSTextViewHelper.textView_candidates_forSelectedRange_, 2, NSRange.__typestr__)
+        self.assertArgHasType(TestNSTextViewHelper.textView_shouldSelectCandidateAtIndex_, 1, objc._C_NSUInteger)
+        self.assertResultIsBOOL(TestNSTextViewHelper.textView_shouldSelectCandidateAtIndex_)
+
+    @min_os_level('10.14')
+    def testProtocols10_14(self):
+        objc.protocolNamed('NSUserActivityRestoring')
 
 
 if __name__ == "__main__":
