@@ -10,6 +10,10 @@ class TestNSTokenFieldHelper (NSObject):
 
 
 class TestNSTokenField (TestCase):
+    @min_sdk_level('10.7')
+    def testProtocolObjects(self):
+        objc.protocolNamed('NSTokenFieldDelegate')
+
     def testProtocols(self):
         self.assertArgHasType(TestNSTokenFieldHelper.tokenField_completionsForSubstring_indexOfToken_indexOfSelectedItem_, 2, objc._C_NSInteger)
         self.assertArgHasType(TestNSTokenFieldHelper.tokenField_completionsForSubstring_indexOfToken_indexOfSelectedItem_, 3, b'o^' + objc._C_NSInteger)
