@@ -1,11 +1,6 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 class TestNSURLHandle (TestCase):
     def testMethods(self):
@@ -33,5 +28,8 @@ class TestNSURLHandle (TestCase):
         self.assertResultIsBOOL(NSURLHandle.writeProperty_forKey_)
         self.assertResultIsBOOL(NSURLHandle.writeData_)
 
+    def testProtocols(self):
+        objc.protocolNamed('NSURLHandleClient')
+
 if __name__ == "__main__":
     main()
