@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 import Foundation
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class UserNotificationHelper (Foundation.NSObject):
     def userNotificationCenter_shouldPresentNotification_(self, a, b): pass
 
@@ -17,6 +12,8 @@ class TestNSUserNotification (TestCase):
         self.assertEqual(Foundation.NSUserNotificationActivationTypeNone, 0)
         self.assertEqual(Foundation.NSUserNotificationActivationTypeContentsClicked, 1)
         self.assertEqual(Foundation.NSUserNotificationActivationTypeActionButtonClicked, 2)
+        self.assertEqual(Foundation.NSUserNotificationActivationTypeReplied, 3)
+        self.assertEqual(Foundation.NSUserNotificationActivationTypeAdditionalActionClicked, 4)
 
         self.assertIsInstance(Foundation.NSUserNotificationDefaultSoundName, unicode)
 
@@ -28,9 +25,20 @@ class TestNSUserNotification (TestCase):
         self.assertResultIsBOOL(obj.hasActionButton)
         self.assertArgIsBOOL(obj.setHasActionButton_, 0)
 
+    @min_os_level('10.9')
+    def testMethods10_9(self):
+        obj = Foundation.NSUserNotification.alloc().init()
+        self.assertResultIsBOOL(obj.hasReplyButton)
+        self.assertArgIsBOOL(obj.setHasReplyButton_, 0)
+
     @min_os_level('10.8')
     def testProtocol10_8(self):
         self.assertResultIsBOOL(UserNotificationHelper.userNotificationCenter_shouldPresentNotification_)
 
+
+    @min_os_level('10.10')
+    def testProtocolsObjects(self):
+        objc.protocolNamed('NSUserNotificationCenterDelegate')
+
 if __name__ == "__main__":
     main()
